/********************************************************************************
** Form generated from reading UI file 'qseditoptions.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef QSEDITOPTIONS_H
#define QSEDITOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_qseditoptions
{
public:
    QVBoxLayout *verticalLayout;
    QDialogButtonBox *buttonBoxOptionsDialog;
    QTabWidget *tabWidget;
    QWidget *tabMidiClock;
    QGroupBox *groupBoxMetaEvents;
    QLabel *label_meta_events;
    QWidget *metaLayoutWidget;
    QHBoxLayout *horizontalLayout_6;
    QLineEdit *lineEditTempoTrack;
    QPushButton *pushButtonTempoTrack;
    QLabel *textLabelTempoTrack;
    QLabel *label_clock_precision;
    QComboBox *comboBoxBpmPrecision;
    QLabel *label;
    QLineEdit *lineEditClientId;
    QLabel *portsClocksLabel;
    QScrollArea *clocksScrollArea;
    QWidget *scrollAreaWidgetContents;
    QLabel *label_2;
    QWidget *horizontalLayoutWidget_2;
    QHBoxLayout *hLayoutMidiOutBuss;
    QCheckBox *checkBoxMidiOutBuss;
    QLabel *labelMidiOutBuss;
    QComboBox *comboBoxMidiOutBuss;
    QWidget *layoutWidgetCtrlOut;
    QGridLayout *gridLayout_7;
    QHBoxLayout *horizLayoutClockStartModulo;
    QLabel *labelClockStartModulo;
    QSpinBox *spinBoxClockStartModulo;
    QCheckBox *ioPortsMappedCheck;
    QLabel *label_20;
    QLineEdit *lineEditBussOverride;
    QPushButton *pushButtonStoreMap;
    QPushButton *pushButtonRemoveMap;
    QGroupBox *groupBox_2;
    QGroupBox *groupBox_10;
    QWidget *tabMidiInput;
    QGroupBox *groupBoxInputOptions;
    QLabel *label_5;
    QWidget *ioLayoutWidget;
    QGridLayout *gridLayout_9;
    QCheckBox *checkBoxVirtualPorts;
    QCheckBox *checkBoxRecordByBuss;
    QLineEdit *lineEditOutputCount;
    QLabel *label_outputs;
    QLineEdit *lineEditInputCount;
    QCheckBox *checkBoxAutoEnableVirtual;
    QLabel *label_inputs;
    QCheckBox *checkBoxRecordByChannel;
    QLabel *inputBussesLabel;
    QScrollArea *inputsScrollArea;
    QWidget *scrollAreaWidgetContents_2;
    QWidget *horizontalLayoutWidget;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *checkBoxMidiInBuss;
    QLabel *labelMidiCtrlIn;
    QComboBox *comboBoxMidiInBuss;
    QGroupBox *groupBox_3;
    QWidget *tabDisplay;
    QGroupBox *groupBoxBooleanOptions;
    QWidget *layoutWidgetBooleanOptions;
    QGridLayout *gridLayout;
    QCheckBox *checkBoxLongBussNames;
    QCheckBox *checkBoxVerbose;
    QCheckBox *checkBoxPairBussNames;
    QCheckBox *checkBoxGlobalSeqFeature;
    QCheckBox *checkBoxDoubleClickEdit;
    QCheckBox *checkBoxQuiet;
    QCheckBox *checkBoxSwapCoordinates;
    QCheckBox *checkBoxDarkTheme;
    QCheckBox *checkBoxElliptical;
    QCheckBox *checkBoxShowFullRecentPaths;
    QCheckBox *checkBoxLoadMostRecent;
    QCheckBox *checkBoxFollowProgress;
    QCheckBox *checkBoxBoldGridSlots;
    QLabel *label_7;
    QCheckBox *checkBoxLockMainWindow;
    QCheckBox *checkBoxGridlinesThick;
    QCheckBox *checkBox_2;
    QWidget *layoutWidgetGuiOptions;
    QGridLayout *gridLayoutUiValues;
    QCheckBox *checkBoxProgressBoxShown;
    QLineEdit *lineEditUiScalingHeight;
    QLineEdit *lineEditSetSize;
    QLabel *labelProgressBoxSize;
    QLineEdit *lineEditFingerprintSize;
    QLabel *labelFingerprintSize;
    QLabel *labelEditorKeyHeight;
    QLineEdit *lineEditGridSpacing;
    QLineEdit *lineEditSetSizeColumns;
    QLineEdit *lineEditProgressBoxHeight;
    QLineEdit *lineEditProgressBox;
    QLabel *label_x2;
    QSpinBox *spinKeyHeight;
    QLabel *label_x;
    QLabel *labelSetSizeRows;
    QLabel *label_x3;
    QLabel *labelUiScaling;
    QLineEdit *lineEditUiScaling;
    QLabel *labelRestartNeeded;
    QLabel *label_6;
    QLabel *label_19;
    QGroupBox *groupBox_4;
    QWidget *tabJackSync;
    QGroupBox *r_group_jack_transport;
    QLabel *label_8;
    QLabel *label_4;
    QWidget *layoutWidgetJackServer;
    QGridLayout *gridLayout_5;
    QLabel *label_12;
    QLineEdit *lineEditFrameRate;
    QLabel *label_13;
    QLineEdit *lineEditPeriod;
    QLabel *label_15;
    QLineEdit *lineEditNperiod;
    QLabel *label_16;
    QLineEdit *lineEditTicksPerBeat;
    QLabel *label_17;
    QLineEdit *lineEditBeatsPerMinute;
    QLabel *label_18;
    QComboBox *combo_box_buffer_size;
    QPushButton *alsaJackButton;
    QWidget *layoutWidgetJackTransport;
    QVBoxLayout *vertLayoutJackTransportMidi;
    QCheckBox *chkJackConditional;
    QCheckBox *chkJackMaster;
    QCheckBox *chkJackTransport;
    QCheckBox *chkJackNative;
    QCheckBox *chkJackAutoConnect;
    QGroupBox *r_group_jack_start;
    QLabel *label_9;
    QLabel *label_14;
    QWidget *layoutWidgetJack;
    QVBoxLayout *radio_group_layout;
    QRadioButton *radio_live_mode;
    QRadioButton *radio_song_mode;
    QWidget *layoutWidgetJackConnect;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_25;
    QPushButton *btnJackConnect;
    QPushButton *btnJackDisconnect;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox;
    QWidget *tabPlayOptions;
    QGroupBox *group_flags;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout_8;
    QCheckBox *chkNoteResume;
    QCheckBox *chkUseFilesPPQN;
    QCheckBox *chkSongRecordSnap;
    QCheckBox *chkAddTimeSig;
    QGroupBox *group_setsmode;
    QRadioButton *radio_setsmode_normal;
    QRadioButton *radio_setsmode_autoarm;
    QRadioButton *radio_setsmode_additive;
    QRadioButton *radio_setsmode_allsets;
    QGroupBox *group_startmode;
    QRadioButton *radio_startmode_live;
    QRadioButton *radio_startmode_song;
    QRadioButton *radio_startmode_auto;
    QLabel *label_ppqn;
    QLabel *label_ppqn_2;
    QComboBox *combo_box_ppqn;
    QGroupBox *groupBox_5;
    QWidget *tabMetronome;
    QWidget *metroLayoutWidget;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_metro_timesig;
    QGridLayout *gridLayout_3;
    QLabel *label_metro_beat_width;
    QLineEdit *lineedit_metro_beats_per_bar;
    QLabel *label_metro_bpb;
    QLineEdit *lineedit_metro_beat_width;
    QSpacerItem *verticalSpacer_2;
    QGridLayout *gridLayout_4;
    QLabel *label_metro_count;
    QLabel *label_metro_count_in;
    QLineEdit *lineedit_metro_count_in;
    QCheckBox *checkbox_metro_count_in;
    QCheckBox *checkbox_metro_recording;
    QLineEdit *lineedit_metro_recording_measures;
    QWidget *metroLayoutWidget2;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayout_2;
    QLabel *label_output_specs;
    QLabel *label_metro_main_note;
    QLabel *label_metro_sub_notes;
    QLabel *label_metro_patch;
    QLineEdit *lineedit_metro_main_patch;
    QLineEdit *lineedit_metro_sub_patch;
    QLabel *label_metro_note;
    QLineEdit *lineedit_metro_main_note;
    QLineEdit *lineedit_metro_sub_note;
    QLabel *label_metro_velocity;
    QLineEdit *lineedit_metro_main_velocity;
    QLineEdit *lineedit_metro_sub_velocity;
    QLabel *label_metro_length_fraction;
    QLineEdit *lineedit_metro_main_fraction;
    QLineEdit *lineedit_metro_sub_fraction;
    QSpacerItem *verticalSpacer_3;
    QPushButton *button_metro_reload;
    QWidget *layoutWidgetMetro;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout;
    QLabel *label_metro_buss;
    QComboBox *combobox_metro_buss;
    QLabel *label_metro_channel;
    QComboBox *combobox_metro_channel;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_record_bus;
    QComboBox *combobox_metro_record_buss;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_metro_thru_buss;
    QComboBox *combobox_metro_thru_buss;
    QLabel *label_metro_thru_channel;
    QComboBox *combobox_metro_thru_channel;
    QGroupBox *groupBox_6;
    QGroupBox *groupBox_7;
    QWidget *tabPattern;
    QGroupBox *groupBoxNewPattern;
    QWidget *layoutWidget1;
    QVBoxLayout *verticalLayout_7;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *checkBoxNewPatternArm;
    QCheckBox *checkBoxNewPatternRecord;
    QCheckBox *checkBoxNewPatternTighten;
    QCheckBox *checkBoxNewPatternQRecord;
    QCheckBox *checkBoxNewPatternNoteMap;
    QCheckBox *checkBoxNewPatternWrapAround;
    QCheckBox *checkBoxNewPatternThru;
    QCheckBox *checkBoxNewApply;
    QLabel *labelRecordStyle;
    QComboBox *comboBoxRecordStyle;
    QGroupBox *groupBoxRandomization;
    QWidget *layoutWidgetRandomization;
    QGridLayout *gridLayout_6;
    QSpinBox *spinBoxJitter;
    QSpinBox *spinBoxAmplitude;
    QLabel *labelJitter;
    QLabel *labelMidiUnits;
    QLabel *labelJitter2;
    QLabel *labelAmplitude;
    QGroupBox *groupBoxUsrOptions;
    QCheckBox *checkBoxEscapePattern;
    QLabel *label_23;
    QCheckBox *checkBoxSMF0_to_1;
    QLabel *label_21;
    QLabel *label_22;
    QWidget *tabSession;
    QGroupBox *group_session;
    QRadioButton *radio_session_none;
    QRadioButton *radio_session_nsm;
    QRadioButton *radio_session_jack;
    QLabel *label_10;
    QLabel *label_session;
    QLabel *label_nsm_url;
    QLineEdit *lineEditNsmUrl;
    QGroupBox *groupBoxSaveAtExit;
    QCheckBox *checkBoxSaveRc;
    QCheckBox *checkBoxSaveUsr;
    QCheckBox *checkBoxSaveMutes;
    QCheckBox *checkBoxSavePlaylist;
    QCheckBox *checkBoxSaveCtrl;
    QCheckBox *checkBoxSaveDrums;
    QCheckBox *checkBoxActiveRc;
    QCheckBox *checkBoxActiveUsr;
    QCheckBox *checkBoxActiveMutes;
    QCheckBox *checkBoxActivePlaylist;
    QCheckBox *checkBoxActiveCtrl;
    QCheckBox *checkBoxActiveDrums;
    QLabel *label_cfg_active;
    QLabel *label_cfg_save;
    QLineEdit *lineEditRc;
    QLineEdit *lineEditUsr;
    QLineEdit *lineEditMutes;
    QLineEdit *lineEditPlaylist;
    QLineEdit *lineEditCtrl;
    QLineEdit *lineEditDrums;
    QLabel *label_cfg_basename;
    QLineEdit *lineEditPalette;
    QCheckBox *checkBoxActivePalette;
    QCheckBox *checkBoxSavePalette;
    QLabel *label_cfg_active_2;
    QLabel *label_cfg_save_2;
    QLabel *label_cfg_basename_2;
    QCheckBox *checkBoxActiveStyleSheet;
    QCheckBox *checkBoxSaveStyleSheet;
    QLineEdit *lineEditStyleSheet;
    QPushButton *pushButtonSavePalette;
    QLabel *label_11;
    QPushButton *pushButtonLoadRc;
    QPushButton *pushButtonLoadUsr;
    QPushButton *pushButtonLoadMutes;
    QPushButton *pushButtonLoadPlaylist;
    QPushButton *pushButtonLoadPalette;
    QPushButton *pushButtonLoadCtrl;
    QPushButton *pushButtonLoadDrums;
    QPushButton *pushButtonLoadStyleSheet;
    QLabel *label_cannot_alter;
    QCheckBox *checkBoxSavePatches;
    QCheckBox *checkBoxActivePatches;
    QLineEdit *lineEditPatches;
    QPushButton *pushButtonLoadPatches;
    QPushButton *pushButtonSavePatches;
    QLabel *label_exit_required;
    QLabel *label_3;
    QLabel *label_24;
    QLineEdit *lineEditBrowser;
    QLineEdit *lineEditPdfViewer;
    QPushButton *pushButtonSetBrowser;
    QPushButton *pushButtonSetPdfViewer;
    QGroupBox *groupBox_8;
    QPushButton *pushButtonReload;

    void setupUi(QDialog *qseditoptions)
    {
        if (qseditoptions->objectName().isEmpty())
            qseditoptions->setObjectName(QString::fromUtf8("qseditoptions"));
        qseditoptions->resize(750, 670);
        QFont font;
        font.setPointSize(11);
        qseditoptions->setFont(font);
        verticalLayout = new QVBoxLayout(qseditoptions);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        buttonBoxOptionsDialog = new QDialogButtonBox(qseditoptions);
        buttonBoxOptionsDialog->setObjectName(QString::fromUtf8("buttonBoxOptionsDialog"));
        buttonBoxOptionsDialog->setMaximumSize(QSize(580, 16777215));
        buttonBoxOptionsDialog->setStandardButtons(QDialogButtonBox::StandardButton::Apply|QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok|QDialogButtonBox::StandardButton::Reset);
        buttonBoxOptionsDialog->setCenterButtons(false);

        verticalLayout->addWidget(buttonBoxOptionsDialog);

        tabWidget = new QTabWidget(qseditoptions);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        tabWidget->setEnabled(true);
        QFont font1;
        font1.setPointSize(11);
        font1.setBold(true);
        tabWidget->setFont(font1);
        tabMidiClock = new QWidget();
        tabMidiClock->setObjectName(QString::fromUtf8("tabMidiClock"));
        groupBoxMetaEvents = new QGroupBox(tabMidiClock);
        groupBoxMetaEvents->setObjectName(QString::fromUtf8("groupBoxMetaEvents"));
        groupBoxMetaEvents->setGeometry(QRect(10, 422, 601, 71));
        QFont font2;
        font2.setPointSize(11);
        font2.setBold(false);
        groupBoxMetaEvents->setFont(font2);
        groupBoxMetaEvents->setFlat(true);
        label_meta_events = new QLabel(groupBoxMetaEvents);
        label_meta_events->setObjectName(QString::fromUtf8("label_meta_events"));
        label_meta_events->setGeometry(QRect(20, 10, 141, 17));
        label_meta_events->setFont(font1);
        metaLayoutWidget = new QWidget(groupBoxMetaEvents);
        metaLayoutWidget->setObjectName(QString::fromUtf8("metaLayoutWidget"));
        metaLayoutWidget->setGeometry(QRect(11, 30, 571, 31));
        horizontalLayout_6 = new QHBoxLayout(metaLayoutWidget);
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        horizontalLayout_6->setContentsMargins(0, 0, 0, 0);
        lineEditTempoTrack = new QLineEdit(metaLayoutWidget);
        lineEditTempoTrack->setObjectName(QString::fromUtf8("lineEditTempoTrack"));
        lineEditTempoTrack->setEnabled(true);
        lineEditTempoTrack->setMinimumSize(QSize(0, 28));
        lineEditTempoTrack->setMaxLength(4);
        lineEditTempoTrack->setFrame(true);
        lineEditTempoTrack->setReadOnly(false);

        horizontalLayout_6->addWidget(lineEditTempoTrack);

        pushButtonTempoTrack = new QPushButton(metaLayoutWidget);
        pushButtonTempoTrack->setObjectName(QString::fromUtf8("pushButtonTempoTrack"));
        pushButtonTempoTrack->setMinimumSize(QSize(0, 28));
        pushButtonTempoTrack->setMaximumSize(QSize(140, 16777215));

        horizontalLayout_6->addWidget(pushButtonTempoTrack);

        textLabelTempoTrack = new QLabel(metaLayoutWidget);
        textLabelTempoTrack->setObjectName(QString::fromUtf8("textLabelTempoTrack"));
        textLabelTempoTrack->setFont(font1);

        horizontalLayout_6->addWidget(textLabelTempoTrack);

        label_clock_precision = new QLabel(metaLayoutWidget);
        label_clock_precision->setObjectName(QString::fromUtf8("label_clock_precision"));
        label_clock_precision->setFont(font1);
        label_clock_precision->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_6->addWidget(label_clock_precision);

        comboBoxBpmPrecision = new QComboBox(metaLayoutWidget);
        comboBoxBpmPrecision->setObjectName(QString::fromUtf8("comboBoxBpmPrecision"));
        comboBoxBpmPrecision->setMinimumSize(QSize(0, 28));
        comboBoxBpmPrecision->setMaximumSize(QSize(64, 16777215));

        horizontalLayout_6->addWidget(comboBoxBpmPrecision);

        horizontalLayout_6->setStretch(0, 4);
        horizontalLayout_6->setStretch(1, 8);
        horizontalLayout_6->setStretch(2, 20);
        horizontalLayout_6->setStretch(3, 20);
        horizontalLayout_6->setStretch(4, 8);
        label = new QLabel(tabMidiClock);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(30, 520, 181, 17));
        label->setFont(font1);
        lineEditClientId = new QLineEdit(tabMidiClock);
        lineEditClientId->setObjectName(QString::fromUtf8("lineEditClientId"));
        lineEditClientId->setEnabled(false);
        lineEditClientId->setGeometry(QRect(220, 510, 185, 28));
        lineEditClientId->setReadOnly(true);
        portsClocksLabel = new QLabel(tabMidiClock);
        portsClocksLabel->setObjectName(QString::fromUtf8("portsClocksLabel"));
        portsClocksLabel->setGeometry(QRect(10, 10, 240, 17));
        portsClocksLabel->setMinimumSize(QSize(240, 0));
        portsClocksLabel->setFont(font1);
        clocksScrollArea = new QScrollArea(tabMidiClock);
        clocksScrollArea->setObjectName(QString::fromUtf8("clocksScrollArea"));
        clocksScrollArea->setGeometry(QRect(10, 40, 701, 241));
        clocksScrollArea->setFont(font2);
        clocksScrollArea->setFrameShape(QFrame::Shape::NoFrame);
        clocksScrollArea->setLineWidth(2);
        clocksScrollArea->setMidLineWidth(1);
        clocksScrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAsNeeded);
        clocksScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName(QString::fromUtf8("scrollAreaWidgetContents"));
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 701, 241));
        clocksScrollArea->setWidget(scrollAreaWidgetContents);
        label_2 = new QLabel(tabMidiClock);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(420, 12, 121, 17));
        label_2->setFont(font1);
        horizontalLayoutWidget_2 = new QWidget(tabMidiClock);
        horizontalLayoutWidget_2->setObjectName(QString::fromUtf8("horizontalLayoutWidget_2"));
        horizontalLayoutWidget_2->setGeometry(QRect(28, 370, 573, 45));
        hLayoutMidiOutBuss = new QHBoxLayout(horizontalLayoutWidget_2);
        hLayoutMidiOutBuss->setObjectName(QString::fromUtf8("hLayoutMidiOutBuss"));
        hLayoutMidiOutBuss->setContentsMargins(0, 0, 0, 0);
        checkBoxMidiOutBuss = new QCheckBox(horizontalLayoutWidget_2);
        checkBoxMidiOutBuss->setObjectName(QString::fromUtf8("checkBoxMidiOutBuss"));

        hLayoutMidiOutBuss->addWidget(checkBoxMidiOutBuss);

        labelMidiOutBuss = new QLabel(horizontalLayoutWidget_2);
        labelMidiOutBuss->setObjectName(QString::fromUtf8("labelMidiOutBuss"));
        labelMidiOutBuss->setFont(font1);

        hLayoutMidiOutBuss->addWidget(labelMidiOutBuss);

        comboBoxMidiOutBuss = new QComboBox(horizontalLayoutWidget_2);
        comboBoxMidiOutBuss->setObjectName(QString::fromUtf8("comboBoxMidiOutBuss"));

        hLayoutMidiOutBuss->addWidget(comboBoxMidiOutBuss);

        hLayoutMidiOutBuss->setStretch(0, 1);
        hLayoutMidiOutBuss->setStretch(1, 8);
        hLayoutMidiOutBuss->setStretch(2, 10);
        layoutWidgetCtrlOut = new QWidget(tabMidiClock);
        layoutWidgetCtrlOut->setObjectName(QString::fromUtf8("layoutWidgetCtrlOut"));
        layoutWidgetCtrlOut->setGeometry(QRect(30, 300, 569, 70));
        gridLayout_7 = new QGridLayout(layoutWidgetCtrlOut);
        gridLayout_7->setObjectName(QString::fromUtf8("gridLayout_7"));
        gridLayout_7->setContentsMargins(0, 0, 0, 0);
        horizLayoutClockStartModulo = new QHBoxLayout();
        horizLayoutClockStartModulo->setObjectName(QString::fromUtf8("horizLayoutClockStartModulo"));
        labelClockStartModulo = new QLabel(layoutWidgetCtrlOut);
        labelClockStartModulo->setObjectName(QString::fromUtf8("labelClockStartModulo"));
        labelClockStartModulo->setFont(font1);

        horizLayoutClockStartModulo->addWidget(labelClockStartModulo);

        spinBoxClockStartModulo = new QSpinBox(layoutWidgetCtrlOut);
        spinBoxClockStartModulo->setObjectName(QString::fromUtf8("spinBoxClockStartModulo"));
        spinBoxClockStartModulo->setMinimumSize(QSize(82, 28));
        spinBoxClockStartModulo->setMinimum(1);
        spinBoxClockStartModulo->setMaximum(1024);
        spinBoxClockStartModulo->setValue(64);

        horizLayoutClockStartModulo->addWidget(spinBoxClockStartModulo);

        horizLayoutClockStartModulo->setStretch(0, 8);
        horizLayoutClockStartModulo->setStretch(1, 1);

        gridLayout_7->addLayout(horizLayoutClockStartModulo, 0, 0, 1, 2);

        ioPortsMappedCheck = new QCheckBox(layoutWidgetCtrlOut);
        ioPortsMappedCheck->setObjectName(QString::fromUtf8("ioPortsMappedCheck"));
        ioPortsMappedCheck->setEnabled(true);
        ioPortsMappedCheck->setFont(font2);

        gridLayout_7->addWidget(ioPortsMappedCheck, 0, 2, 1, 2);

        label_20 = new QLabel(layoutWidgetCtrlOut);
        label_20->setObjectName(QString::fromUtf8("label_20"));
        label_20->setFont(font1);

        gridLayout_7->addWidget(label_20, 1, 0, 1, 1);

        lineEditBussOverride = new QLineEdit(layoutWidgetCtrlOut);
        lineEditBussOverride->setObjectName(QString::fromUtf8("lineEditBussOverride"));
        lineEditBussOverride->setMinimumSize(QSize(0, 28));

        gridLayout_7->addWidget(lineEditBussOverride, 1, 1, 1, 1);

        pushButtonStoreMap = new QPushButton(layoutWidgetCtrlOut);
        pushButtonStoreMap->setObjectName(QString::fromUtf8("pushButtonStoreMap"));
        pushButtonStoreMap->setMinimumSize(QSize(80, 32));

        gridLayout_7->addWidget(pushButtonStoreMap, 1, 2, 1, 1);

        pushButtonRemoveMap = new QPushButton(layoutWidgetCtrlOut);
        pushButtonRemoveMap->setObjectName(QString::fromUtf8("pushButtonRemoveMap"));
        pushButtonRemoveMap->setMinimumSize(QSize(0, 32));

        gridLayout_7->addWidget(pushButtonRemoveMap, 1, 3, 1, 1);

        groupBox_2 = new QGroupBox(tabMidiClock);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        groupBox_2->setGeometry(QRect(10, 290, 601, 131));
        groupBox_10 = new QGroupBox(tabMidiClock);
        groupBox_10->setObjectName(QString::fromUtf8("groupBox_10"));
        groupBox_10->setGeometry(QRect(10, 496, 601, 51));
        tabWidget->addTab(tabMidiClock, QString());
        groupBoxMetaEvents->raise();
        groupBox_2->raise();
        groupBox_10->raise();
        label->raise();
        lineEditClientId->raise();
        portsClocksLabel->raise();
        clocksScrollArea->raise();
        label_2->raise();
        horizontalLayoutWidget_2->raise();
        layoutWidgetCtrlOut->raise();
        tabMidiInput = new QWidget();
        tabMidiInput->setObjectName(QString::fromUtf8("tabMidiInput"));
        groupBoxInputOptions = new QGroupBox(tabMidiInput);
        groupBoxInputOptions->setObjectName(QString::fromUtf8("groupBoxInputOptions"));
        groupBoxInputOptions->setGeometry(QRect(10, 370, 611, 161));
        groupBoxInputOptions->setFont(font2);
        groupBoxInputOptions->setFlat(false);
        groupBoxInputOptions->setCheckable(false);
        label_5 = new QLabel(groupBoxInputOptions);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        label_5->setGeometry(QRect(8, 10, 181, 17));
        label_5->setFont(font1);
        ioLayoutWidget = new QWidget(groupBoxInputOptions);
        ioLayoutWidget->setObjectName(QString::fromUtf8("ioLayoutWidget"));
        ioLayoutWidget->setGeometry(QRect(20, 38, 571, 129));
        gridLayout_9 = new QGridLayout(ioLayoutWidget);
        gridLayout_9->setObjectName(QString::fromUtf8("gridLayout_9"));
        gridLayout_9->setContentsMargins(0, 0, 0, 0);
        checkBoxVirtualPorts = new QCheckBox(ioLayoutWidget);
        checkBoxVirtualPorts->setObjectName(QString::fromUtf8("checkBoxVirtualPorts"));

        gridLayout_9->addWidget(checkBoxVirtualPorts, 2, 0, 1, 1);

        checkBoxRecordByBuss = new QCheckBox(ioLayoutWidget);
        checkBoxRecordByBuss->setObjectName(QString::fromUtf8("checkBoxRecordByBuss"));

        gridLayout_9->addWidget(checkBoxRecordByBuss, 0, 0, 1, 3);

        lineEditOutputCount = new QLineEdit(ioLayoutWidget);
        lineEditOutputCount->setObjectName(QString::fromUtf8("lineEditOutputCount"));
        lineEditOutputCount->setMaximumSize(QSize(48, 16777215));
        lineEditOutputCount->setMaxLength(2);
        lineEditOutputCount->setFrame(true);
        lineEditOutputCount->setClearButtonEnabled(false);

        gridLayout_9->addWidget(lineEditOutputCount, 2, 2, 1, 1);

        label_outputs = new QLabel(ioLayoutWidget);
        label_outputs->setObjectName(QString::fromUtf8("label_outputs"));
        label_outputs->setMaximumSize(QSize(96, 16777215));
        label_outputs->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_9->addWidget(label_outputs, 2, 1, 1, 1);

        lineEditInputCount = new QLineEdit(ioLayoutWidget);
        lineEditInputCount->setObjectName(QString::fromUtf8("lineEditInputCount"));
        lineEditInputCount->setMaximumSize(QSize(48, 16777215));
        lineEditInputCount->setMaxLength(2);

        gridLayout_9->addWidget(lineEditInputCount, 2, 4, 1, 1);

        checkBoxAutoEnableVirtual = new QCheckBox(ioLayoutWidget);
        checkBoxAutoEnableVirtual->setObjectName(QString::fromUtf8("checkBoxAutoEnableVirtual"));

        gridLayout_9->addWidget(checkBoxAutoEnableVirtual, 3, 0, 1, 2);

        label_inputs = new QLabel(ioLayoutWidget);
        label_inputs->setObjectName(QString::fromUtf8("label_inputs"));
        label_inputs->setMaximumSize(QSize(96, 16777215));
        label_inputs->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_9->addWidget(label_inputs, 2, 3, 1, 1);

        checkBoxRecordByChannel = new QCheckBox(ioLayoutWidget);
        checkBoxRecordByChannel->setObjectName(QString::fromUtf8("checkBoxRecordByChannel"));

        gridLayout_9->addWidget(checkBoxRecordByChannel, 1, 0, 1, 3);

        inputBussesLabel = new QLabel(tabMidiInput);
        inputBussesLabel->setObjectName(QString::fromUtf8("inputBussesLabel"));
        inputBussesLabel->setGeometry(QRect(16, 8, 129, 17));
        inputBussesLabel->setFont(font1);
        inputsScrollArea = new QScrollArea(tabMidiInput);
        inputsScrollArea->setObjectName(QString::fromUtf8("inputsScrollArea"));
        inputsScrollArea->setGeometry(QRect(6, 32, 691, 251));
        inputsScrollArea->setFont(font2);
        inputsScrollArea->setFrameShape(QFrame::Shape::NoFrame);
        inputsScrollArea->setLineWidth(2);
        inputsScrollArea->setMidLineWidth(1);
        inputsScrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAsNeeded);
        inputsScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents_2 = new QWidget();
        scrollAreaWidgetContents_2->setObjectName(QString::fromUtf8("scrollAreaWidgetContents_2"));
        scrollAreaWidgetContents_2->setGeometry(QRect(0, 0, 691, 251));
        inputsScrollArea->setWidget(scrollAreaWidgetContents_2);
        horizontalLayoutWidget = new QWidget(tabMidiInput);
        horizontalLayoutWidget->setObjectName(QString::fromUtf8("horizontalLayoutWidget"));
        horizontalLayoutWidget->setGeometry(QRect(32, 316, 585, 49));
        horizontalLayout_2 = new QHBoxLayout(horizontalLayoutWidget);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        checkBoxMidiInBuss = new QCheckBox(horizontalLayoutWidget);
        checkBoxMidiInBuss->setObjectName(QString::fromUtf8("checkBoxMidiInBuss"));

        horizontalLayout_2->addWidget(checkBoxMidiInBuss);

        labelMidiCtrlIn = new QLabel(horizontalLayoutWidget);
        labelMidiCtrlIn->setObjectName(QString::fromUtf8("labelMidiCtrlIn"));
        labelMidiCtrlIn->setFont(font1);

        horizontalLayout_2->addWidget(labelMidiCtrlIn);

        comboBoxMidiInBuss = new QComboBox(horizontalLayoutWidget);
        comboBoxMidiInBuss->setObjectName(QString::fromUtf8("comboBoxMidiInBuss"));

        horizontalLayout_2->addWidget(comboBoxMidiInBuss);

        horizontalLayout_2->setStretch(0, 1);
        horizontalLayout_2->setStretch(1, 8);
        horizontalLayout_2->setStretch(2, 10);
        groupBox_3 = new QGroupBox(tabMidiInput);
        groupBox_3->setObjectName(QString::fromUtf8("groupBox_3"));
        groupBox_3->setGeometry(QRect(10, 299, 611, 81));
        tabWidget->addTab(tabMidiInput, QString());
        groupBox_3->raise();
        groupBoxInputOptions->raise();
        inputBussesLabel->raise();
        inputsScrollArea->raise();
        horizontalLayoutWidget->raise();
        tabDisplay = new QWidget();
        tabDisplay->setObjectName(QString::fromUtf8("tabDisplay"));
        groupBoxBooleanOptions = new QGroupBox(tabDisplay);
        groupBoxBooleanOptions->setObjectName(QString::fromUtf8("groupBoxBooleanOptions"));
        groupBoxBooleanOptions->setGeometry(QRect(10, 220, 589, 281));
        groupBoxBooleanOptions->setFont(font2);
        groupBoxBooleanOptions->setFlat(false);
        layoutWidgetBooleanOptions = new QWidget(groupBoxBooleanOptions);
        layoutWidgetBooleanOptions->setObjectName(QString::fromUtf8("layoutWidgetBooleanOptions"));
        layoutWidgetBooleanOptions->setGeometry(QRect(8, 4, 570, 275));
        gridLayout = new QGridLayout(layoutWidgetBooleanOptions);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        checkBoxLongBussNames = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxLongBussNames->setObjectName(QString::fromUtf8("checkBoxLongBussNames"));
        checkBoxLongBussNames->setMinimumSize(QSize(0, 24));
        checkBoxLongBussNames->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxLongBussNames, 4, 0, 1, 1);

        checkBoxVerbose = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxVerbose->setObjectName(QString::fromUtf8("checkBoxVerbose"));
        checkBoxVerbose->setEnabled(false);
        checkBoxVerbose->setMinimumSize(QSize(0, 24));
        checkBoxVerbose->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxVerbose, 1, 0, 1, 1);

        checkBoxPairBussNames = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxPairBussNames->setObjectName(QString::fromUtf8("checkBoxPairBussNames"));
        checkBoxPairBussNames->setMinimumSize(QSize(0, 24));
        checkBoxPairBussNames->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxPairBussNames, 4, 1, 1, 1);

        checkBoxGlobalSeqFeature = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxGlobalSeqFeature->setObjectName(QString::fromUtf8("checkBoxGlobalSeqFeature"));
        checkBoxGlobalSeqFeature->setMinimumSize(QSize(0, 24));
        checkBoxGlobalSeqFeature->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxGlobalSeqFeature, 3, 1, 1, 1);

        checkBoxDoubleClickEdit = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxDoubleClickEdit->setObjectName(QString::fromUtf8("checkBoxDoubleClickEdit"));
        checkBoxDoubleClickEdit->setMinimumSize(QSize(0, 24));
        checkBoxDoubleClickEdit->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxDoubleClickEdit, 2, 1, 1, 1);

        checkBoxQuiet = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxQuiet->setObjectName(QString::fromUtf8("checkBoxQuiet"));
        checkBoxQuiet->setMinimumSize(QSize(0, 24));
        checkBoxQuiet->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxQuiet, 1, 1, 1, 1);

        checkBoxSwapCoordinates = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxSwapCoordinates->setObjectName(QString::fromUtf8("checkBoxSwapCoordinates"));
        checkBoxSwapCoordinates->setMinimumSize(QSize(0, 24));
        checkBoxSwapCoordinates->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxSwapCoordinates, 6, 0, 1, 1);

        checkBoxDarkTheme = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxDarkTheme->setObjectName(QString::fromUtf8("checkBoxDarkTheme"));

        gridLayout->addWidget(checkBoxDarkTheme, 5, 1, 1, 1);

        checkBoxElliptical = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxElliptical->setObjectName(QString::fromUtf8("checkBoxElliptical"));

        gridLayout->addWidget(checkBoxElliptical, 6, 1, 1, 1);

        checkBoxShowFullRecentPaths = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxShowFullRecentPaths->setObjectName(QString::fromUtf8("checkBoxShowFullRecentPaths"));
        checkBoxShowFullRecentPaths->setMinimumSize(QSize(0, 24));
        checkBoxShowFullRecentPaths->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxShowFullRecentPaths, 3, 0, 1, 1);

        checkBoxLoadMostRecent = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxLoadMostRecent->setObjectName(QString::fromUtf8("checkBoxLoadMostRecent"));
        checkBoxLoadMostRecent->setMinimumSize(QSize(0, 24));
        checkBoxLoadMostRecent->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxLoadMostRecent, 2, 0, 1, 1);

        checkBoxFollowProgress = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxFollowProgress->setObjectName(QString::fromUtf8("checkBoxFollowProgress"));

        gridLayout->addWidget(checkBoxFollowProgress, 7, 1, 1, 1);

        checkBoxBoldGridSlots = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxBoldGridSlots->setObjectName(QString::fromUtf8("checkBoxBoldGridSlots"));
        checkBoxBoldGridSlots->setMinimumSize(QSize(0, 24));
        checkBoxBoldGridSlots->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxBoldGridSlots, 7, 0, 1, 1);

        label_7 = new QLabel(layoutWidgetBooleanOptions);
        label_7->setObjectName(QString::fromUtf8("label_7"));
        label_7->setFont(font1);

        gridLayout->addWidget(label_7, 0, 0, 1, 1);

        checkBoxLockMainWindow = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxLockMainWindow->setObjectName(QString::fromUtf8("checkBoxLockMainWindow"));
        checkBoxLockMainWindow->setMinimumSize(QSize(0, 24));
        checkBoxLockMainWindow->setMaximumSize(QSize(16777215, 24));

        gridLayout->addWidget(checkBoxLockMainWindow, 5, 0, 1, 1);

        checkBoxGridlinesThick = new QCheckBox(layoutWidgetBooleanOptions);
        checkBoxGridlinesThick->setObjectName(QString::fromUtf8("checkBoxGridlinesThick"));
        checkBoxGridlinesThick->setEnabled(true);
        QFont font3;
        font3.setPointSize(11);
        font3.setBold(false);
        font3.setItalic(false);
        checkBoxGridlinesThick->setFont(font3);

        gridLayout->addWidget(checkBoxGridlinesThick, 8, 0, 1, 1);

        checkBox_2 = new QCheckBox(layoutWidgetBooleanOptions);
        checkBox_2->setObjectName(QString::fromUtf8("checkBox_2"));
        checkBox_2->setEnabled(false);
        QFont font4;
        font4.setPointSize(11);
        font4.setBold(false);
        font4.setItalic(true);
        checkBox_2->setFont(font4);

        gridLayout->addWidget(checkBox_2, 8, 1, 1, 1);

        layoutWidgetGuiOptions = new QWidget(tabDisplay);
        layoutWidgetGuiOptions->setObjectName(QString::fromUtf8("layoutWidgetGuiOptions"));
        layoutWidgetGuiOptions->setGeometry(QRect(16, 30, 513, 183));
        gridLayoutUiValues = new QGridLayout(layoutWidgetGuiOptions);
        gridLayoutUiValues->setObjectName(QString::fromUtf8("gridLayoutUiValues"));
        gridLayoutUiValues->setContentsMargins(0, 0, 0, 0);
        checkBoxProgressBoxShown = new QCheckBox(layoutWidgetGuiOptions);
        checkBoxProgressBoxShown->setObjectName(QString::fromUtf8("checkBoxProgressBoxShown"));
        checkBoxProgressBoxShown->setFont(font2);

        gridLayoutUiValues->addWidget(checkBoxProgressBoxShown, 3, 4, 1, 1);

        lineEditUiScalingHeight = new QLineEdit(layoutWidgetGuiOptions);
        lineEditUiScalingHeight->setObjectName(QString::fromUtf8("lineEditUiScalingHeight"));
        lineEditUiScalingHeight->setMinimumSize(QSize(0, 28));
        lineEditUiScalingHeight->setMaximumSize(QSize(16777215, 28));
        lineEditUiScalingHeight->setFont(font2);

        gridLayoutUiValues->addWidget(lineEditUiScalingHeight, 1, 3, 1, 1);

        lineEditSetSize = new QLineEdit(layoutWidgetGuiOptions);
        lineEditSetSize->setObjectName(QString::fromUtf8("lineEditSetSize"));
        lineEditSetSize->setEnabled(true);
        lineEditSetSize->setMinimumSize(QSize(0, 28));
        lineEditSetSize->setMaximumSize(QSize(16777215, 28));
        lineEditSetSize->setFont(font2);

        gridLayoutUiValues->addWidget(lineEditSetSize, 2, 1, 1, 1);

        labelProgressBoxSize = new QLabel(layoutWidgetGuiOptions);
        labelProgressBoxSize->setObjectName(QString::fromUtf8("labelProgressBoxSize"));
        labelProgressBoxSize->setEnabled(true);
        labelProgressBoxSize->setFont(font2);

        gridLayoutUiValues->addWidget(labelProgressBoxSize, 3, 0, 1, 1);

        lineEditFingerprintSize = new QLineEdit(layoutWidgetGuiOptions);
        lineEditFingerprintSize->setObjectName(QString::fromUtf8("lineEditFingerprintSize"));
        lineEditFingerprintSize->setEnabled(true);
        lineEditFingerprintSize->setMinimumSize(QSize(0, 28));
        lineEditFingerprintSize->setMaximumSize(QSize(16777215, 28));
        lineEditFingerprintSize->setFont(font2);

        gridLayoutUiValues->addWidget(lineEditFingerprintSize, 4, 1, 1, 1);

        labelFingerprintSize = new QLabel(layoutWidgetGuiOptions);
        labelFingerprintSize->setObjectName(QString::fromUtf8("labelFingerprintSize"));
        labelFingerprintSize->setEnabled(true);
        labelFingerprintSize->setFont(font2);

        gridLayoutUiValues->addWidget(labelFingerprintSize, 4, 0, 1, 1);

        labelEditorKeyHeight = new QLabel(layoutWidgetGuiOptions);
        labelEditorKeyHeight->setObjectName(QString::fromUtf8("labelEditorKeyHeight"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelEditorKeyHeight->sizePolicy().hasHeightForWidth());
        labelEditorKeyHeight->setSizePolicy(sizePolicy);
        labelEditorKeyHeight->setFont(font2);

        gridLayoutUiValues->addWidget(labelEditorKeyHeight, 0, 0, 1, 1);

        lineEditGridSpacing = new QLineEdit(layoutWidgetGuiOptions);
        lineEditGridSpacing->setObjectName(QString::fromUtf8("lineEditGridSpacing"));
        lineEditGridSpacing->setMinimumSize(QSize(0, 28));
        lineEditGridSpacing->setMaximumSize(QSize(16777215, 28));
        lineEditGridSpacing->setFont(font2);

        gridLayoutUiValues->addWidget(lineEditGridSpacing, 1, 4, 1, 1);

        lineEditSetSizeColumns = new QLineEdit(layoutWidgetGuiOptions);
        lineEditSetSizeColumns->setObjectName(QString::fromUtf8("lineEditSetSizeColumns"));
        lineEditSetSizeColumns->setEnabled(true);
        lineEditSetSizeColumns->setMinimumSize(QSize(0, 28));
        lineEditSetSizeColumns->setMaximumSize(QSize(16777215, 28));
        lineEditSetSizeColumns->setFont(font2);

        gridLayoutUiValues->addWidget(lineEditSetSizeColumns, 2, 3, 1, 1);

        lineEditProgressBoxHeight = new QLineEdit(layoutWidgetGuiOptions);
        lineEditProgressBoxHeight->setObjectName(QString::fromUtf8("lineEditProgressBoxHeight"));
        lineEditProgressBoxHeight->setEnabled(true);
        lineEditProgressBoxHeight->setMinimumSize(QSize(0, 28));
        lineEditProgressBoxHeight->setMaximumSize(QSize(16777215, 28));
        lineEditProgressBoxHeight->setFont(font2);

        gridLayoutUiValues->addWidget(lineEditProgressBoxHeight, 3, 3, 1, 1);

        lineEditProgressBox = new QLineEdit(layoutWidgetGuiOptions);
        lineEditProgressBox->setObjectName(QString::fromUtf8("lineEditProgressBox"));
        lineEditProgressBox->setEnabled(true);
        lineEditProgressBox->setMinimumSize(QSize(0, 28));
        lineEditProgressBox->setMaximumSize(QSize(16777215, 28));
        lineEditProgressBox->setFont(font2);

        gridLayoutUiValues->addWidget(lineEditProgressBox, 3, 1, 1, 1);

        label_x2 = new QLabel(layoutWidgetGuiOptions);
        label_x2->setObjectName(QString::fromUtf8("label_x2"));
        label_x2->setEnabled(true);

        gridLayoutUiValues->addWidget(label_x2, 2, 2, 1, 1);

        spinKeyHeight = new QSpinBox(layoutWidgetGuiOptions);
        spinKeyHeight->setObjectName(QString::fromUtf8("spinKeyHeight"));
        spinKeyHeight->setMinimumSize(QSize(65, 28));
        spinKeyHeight->setMaximumSize(QSize(16777215, 28));
        spinKeyHeight->setFont(font2);
        spinKeyHeight->setMinimum(4);
        spinKeyHeight->setMaximum(24);
        spinKeyHeight->setValue(10);

        gridLayoutUiValues->addWidget(spinKeyHeight, 0, 1, 1, 1);

        label_x = new QLabel(layoutWidgetGuiOptions);
        label_x->setObjectName(QString::fromUtf8("label_x"));

        gridLayoutUiValues->addWidget(label_x, 1, 2, 1, 1);

        labelSetSizeRows = new QLabel(layoutWidgetGuiOptions);
        labelSetSizeRows->setObjectName(QString::fromUtf8("labelSetSizeRows"));
        labelSetSizeRows->setEnabled(true);
        labelSetSizeRows->setFont(font2);

        gridLayoutUiValues->addWidget(labelSetSizeRows, 2, 0, 1, 1);

        label_x3 = new QLabel(layoutWidgetGuiOptions);
        label_x3->setObjectName(QString::fromUtf8("label_x3"));
        label_x3->setEnabled(true);

        gridLayoutUiValues->addWidget(label_x3, 3, 2, 1, 1);

        labelUiScaling = new QLabel(layoutWidgetGuiOptions);
        labelUiScaling->setObjectName(QString::fromUtf8("labelUiScaling"));
        labelUiScaling->setFont(font2);

        gridLayoutUiValues->addWidget(labelUiScaling, 1, 0, 1, 1);

        lineEditUiScaling = new QLineEdit(layoutWidgetGuiOptions);
        lineEditUiScaling->setObjectName(QString::fromUtf8("lineEditUiScaling"));
        lineEditUiScaling->setMinimumSize(QSize(0, 28));
        lineEditUiScaling->setMaximumSize(QSize(16777215, 28));
        lineEditUiScaling->setFont(font2);

        gridLayoutUiValues->addWidget(lineEditUiScaling, 1, 1, 1, 1);

        gridLayoutUiValues->setColumnStretch(0, 8);
        labelRestartNeeded = new QLabel(tabDisplay);
        labelRestartNeeded->setObjectName(QString::fromUtf8("labelRestartNeeded"));
        labelRestartNeeded->setGeometry(QRect(240, 10, 281, 16));
        QFont font5;
        font5.setPointSize(10);
        font5.setBold(false);
        font5.setItalic(true);
        labelRestartNeeded->setFont(font5);
        label_6 = new QLabel(tabDisplay);
        label_6->setObjectName(QString::fromUtf8("label_6"));
        label_6->setGeometry(QRect(12, 10, 161, 17));
        label_6->setFont(font1);
        label_19 = new QLabel(tabDisplay);
        label_19->setObjectName(QString::fromUtf8("label_19"));
        label_19->setGeometry(QRect(20, 500, 551, 22));
        label_19->setFont(font5);
        groupBox_4 = new QGroupBox(tabDisplay);
        groupBox_4->setObjectName(QString::fromUtf8("groupBox_4"));
        groupBox_4->setGeometry(QRect(10, 0, 591, 211));
        tabWidget->addTab(tabDisplay, QString());
        groupBox_4->raise();
        groupBoxBooleanOptions->raise();
        layoutWidgetGuiOptions->raise();
        labelRestartNeeded->raise();
        label_6->raise();
        label_19->raise();
        tabJackSync = new QWidget();
        tabJackSync->setObjectName(QString::fromUtf8("tabJackSync"));
        r_group_jack_transport = new QGroupBox(tabJackSync);
        r_group_jack_transport->setObjectName(QString::fromUtf8("r_group_jack_transport"));
        r_group_jack_transport->setGeometry(QRect(10, 10, 611, 241));
        label_8 = new QLabel(r_group_jack_transport);
        label_8->setObjectName(QString::fromUtf8("label_8"));
        label_8->setGeometry(QRect(8, 10, 181, 17));
        label_8->setFont(font1);
        label_4 = new QLabel(r_group_jack_transport);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setGeometry(QRect(364, 8, 201, 17));
        label_4->setFont(font1);
        layoutWidgetJackServer = new QWidget(r_group_jack_transport);
        layoutWidgetJackServer->setObjectName(QString::fromUtf8("layoutWidgetJackServer"));
        layoutWidgetJackServer->setGeometry(QRect(360, 29, 241, 212));
        gridLayout_5 = new QGridLayout(layoutWidgetJackServer);
        gridLayout_5->setObjectName(QString::fromUtf8("gridLayout_5"));
        gridLayout_5->setContentsMargins(0, 0, 0, 0);
        label_12 = new QLabel(layoutWidgetJackServer);
        label_12->setObjectName(QString::fromUtf8("label_12"));
        label_12->setFont(font2);
        label_12->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_5->addWidget(label_12, 0, 0, 1, 1);

        lineEditFrameRate = new QLineEdit(layoutWidgetJackServer);
        lineEditFrameRate->setObjectName(QString::fromUtf8("lineEditFrameRate"));
        lineEditFrameRate->setEnabled(false);
        lineEditFrameRate->setFont(font2);

        gridLayout_5->addWidget(lineEditFrameRate, 0, 1, 1, 1);

        label_13 = new QLabel(layoutWidgetJackServer);
        label_13->setObjectName(QString::fromUtf8("label_13"));
        label_13->setFont(font2);
        label_13->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_5->addWidget(label_13, 1, 0, 1, 1);

        lineEditPeriod = new QLineEdit(layoutWidgetJackServer);
        lineEditPeriod->setObjectName(QString::fromUtf8("lineEditPeriod"));
        lineEditPeriod->setEnabled(false);
        lineEditPeriod->setFont(font2);

        gridLayout_5->addWidget(lineEditPeriod, 1, 1, 1, 1);

        label_15 = new QLabel(layoutWidgetJackServer);
        label_15->setObjectName(QString::fromUtf8("label_15"));
        label_15->setFont(font2);
        label_15->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_5->addWidget(label_15, 2, 0, 1, 1);

        lineEditNperiod = new QLineEdit(layoutWidgetJackServer);
        lineEditNperiod->setObjectName(QString::fromUtf8("lineEditNperiod"));
        lineEditNperiod->setEnabled(false);
        lineEditNperiod->setFont(font2);

        gridLayout_5->addWidget(lineEditNperiod, 2, 1, 1, 1);

        label_16 = new QLabel(layoutWidgetJackServer);
        label_16->setObjectName(QString::fromUtf8("label_16"));
        label_16->setFont(font2);
        label_16->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_5->addWidget(label_16, 3, 0, 1, 1);

        lineEditTicksPerBeat = new QLineEdit(layoutWidgetJackServer);
        lineEditTicksPerBeat->setObjectName(QString::fromUtf8("lineEditTicksPerBeat"));
        lineEditTicksPerBeat->setEnabled(false);
        lineEditTicksPerBeat->setFont(font2);

        gridLayout_5->addWidget(lineEditTicksPerBeat, 3, 1, 1, 1);

        label_17 = new QLabel(layoutWidgetJackServer);
        label_17->setObjectName(QString::fromUtf8("label_17"));
        label_17->setFont(font2);
        label_17->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_5->addWidget(label_17, 4, 0, 1, 1);

        lineEditBeatsPerMinute = new QLineEdit(layoutWidgetJackServer);
        lineEditBeatsPerMinute->setObjectName(QString::fromUtf8("lineEditBeatsPerMinute"));
        lineEditBeatsPerMinute->setEnabled(false);
        lineEditBeatsPerMinute->setFont(font2);

        gridLayout_5->addWidget(lineEditBeatsPerMinute, 4, 1, 1, 1);

        label_18 = new QLabel(layoutWidgetJackServer);
        label_18->setObjectName(QString::fromUtf8("label_18"));
        label_18->setFont(font2);
        label_18->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_5->addWidget(label_18, 5, 0, 1, 1);

        combo_box_buffer_size = new QComboBox(layoutWidgetJackServer);
        combo_box_buffer_size->setObjectName(QString::fromUtf8("combo_box_buffer_size"));
        combo_box_buffer_size->setEnabled(false);
        combo_box_buffer_size->setFont(font2);

        gridLayout_5->addWidget(combo_box_buffer_size, 5, 1, 1, 1);

        gridLayout_5->setColumnStretch(0, 7);
        gridLayout_5->setColumnStretch(1, 8);
        alsaJackButton = new QPushButton(r_group_jack_transport);
        alsaJackButton->setObjectName(QString::fromUtf8("alsaJackButton"));
        alsaJackButton->setGeometry(QRect(20, 200, 151, 32));
        alsaJackButton->setFont(font5);
        alsaJackButton->setFlat(true);
        layoutWidgetJackTransport = new QWidget(tabJackSync);
        layoutWidgetJackTransport->setObjectName(QString::fromUtf8("layoutWidgetJackTransport"));
        layoutWidgetJackTransport->setGeometry(QRect(30, 40, 339, 166));
        vertLayoutJackTransportMidi = new QVBoxLayout(layoutWidgetJackTransport);
        vertLayoutJackTransportMidi->setObjectName(QString::fromUtf8("vertLayoutJackTransportMidi"));
        vertLayoutJackTransportMidi->setContentsMargins(0, 0, 0, 0);
        chkJackConditional = new QCheckBox(layoutWidgetJackTransport);
        chkJackConditional->setObjectName(QString::fromUtf8("chkJackConditional"));
        chkJackConditional->setFont(font2);

        vertLayoutJackTransportMidi->addWidget(chkJackConditional);

        chkJackMaster = new QCheckBox(layoutWidgetJackTransport);
        chkJackMaster->setObjectName(QString::fromUtf8("chkJackMaster"));
        chkJackMaster->setFont(font2);

        vertLayoutJackTransportMidi->addWidget(chkJackMaster);

        chkJackTransport = new QCheckBox(layoutWidgetJackTransport);
        chkJackTransport->setObjectName(QString::fromUtf8("chkJackTransport"));
        chkJackTransport->setFont(font2);

        vertLayoutJackTransportMidi->addWidget(chkJackTransport);

        chkJackNative = new QCheckBox(layoutWidgetJackTransport);
        chkJackNative->setObjectName(QString::fromUtf8("chkJackNative"));
        chkJackNative->setFont(font2);

        vertLayoutJackTransportMidi->addWidget(chkJackNative);

        chkJackAutoConnect = new QCheckBox(layoutWidgetJackTransport);
        chkJackAutoConnect->setObjectName(QString::fromUtf8("chkJackAutoConnect"));
        chkJackAutoConnect->setFont(font2);

        vertLayoutJackTransportMidi->addWidget(chkJackAutoConnect);

        r_group_jack_start = new QGroupBox(tabJackSync);
        r_group_jack_start->setObjectName(QString::fromUtf8("r_group_jack_start"));
        r_group_jack_start->setGeometry(QRect(10, 259, 349, 151));
        r_group_jack_start->setCheckable(false);
        label_9 = new QLabel(r_group_jack_start);
        label_9->setObjectName(QString::fromUtf8("label_9"));
        label_9->setGeometry(QRect(8, 10, 291, 17));
        label_9->setFont(font1);
        label_14 = new QLabel(r_group_jack_start);
        label_14->setObjectName(QString::fromUtf8("label_14"));
        label_14->setGeometry(QRect(168, 54, 173, 49));
        label_14->setFont(font5);
        layoutWidgetJack = new QWidget(tabJackSync);
        layoutWidgetJack->setObjectName(QString::fromUtf8("layoutWidgetJack"));
        layoutWidgetJack->setGeometry(QRect(31, 300, 141, 64));
        radio_group_layout = new QVBoxLayout(layoutWidgetJack);
        radio_group_layout->setObjectName(QString::fromUtf8("radio_group_layout"));
        radio_group_layout->setContentsMargins(0, 0, 0, 0);
        radio_live_mode = new QRadioButton(layoutWidgetJack);
        radio_live_mode->setObjectName(QString::fromUtf8("radio_live_mode"));
        radio_live_mode->setEnabled(false);
        radio_live_mode->setFont(font2);

        radio_group_layout->addWidget(radio_live_mode);

        radio_song_mode = new QRadioButton(layoutWidgetJack);
        radio_song_mode->setObjectName(QString::fromUtf8("radio_song_mode"));
        radio_song_mode->setEnabled(false);
        radio_song_mode->setFont(font2);

        radio_group_layout->addWidget(radio_song_mode);

        layoutWidgetJackConnect = new QWidget(tabJackSync);
        layoutWidgetJackConnect->setObjectName(QString::fromUtf8("layoutWidgetJackConnect"));
        layoutWidgetJackConnect->setGeometry(QRect(380, 270, 211, 121));
        verticalLayout_3 = new QVBoxLayout(layoutWidgetJackConnect);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        label_25 = new QLabel(layoutWidgetJackConnect);
        label_25->setObjectName(QString::fromUtf8("label_25"));
        label_25->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout_3->addWidget(label_25);

        btnJackConnect = new QPushButton(layoutWidgetJackConnect);
        btnJackConnect->setObjectName(QString::fromUtf8("btnJackConnect"));
        btnJackConnect->setFont(font2);

        verticalLayout_3->addWidget(btnJackConnect);

        btnJackDisconnect = new QPushButton(layoutWidgetJackConnect);
        btnJackDisconnect->setObjectName(QString::fromUtf8("btnJackDisconnect"));
        btnJackDisconnect->setFont(font2);

        verticalLayout_3->addWidget(btnJackDisconnect);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        groupBox = new QGroupBox(tabJackSync);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        groupBox->setGeometry(QRect(370, 260, 251, 151));
        tabWidget->addTab(tabJackSync, QString());
        layoutWidgetJackConnect->raise();
        groupBox->raise();
        r_group_jack_transport->raise();
        r_group_jack_start->raise();
        layoutWidgetJack->raise();
        layoutWidgetJackTransport->raise();
        tabPlayOptions = new QWidget();
        tabPlayOptions->setObjectName(QString::fromUtf8("tabPlayOptions"));
        group_flags = new QGroupBox(tabPlayOptions);
        group_flags->setObjectName(QString::fromUtf8("group_flags"));
        group_flags->setGeometry(QRect(9, 9, 701, 151));
        group_flags->setMinimumSize(QSize(0, 120));
        group_flags->setFont(font1);
        layoutWidget = new QWidget(group_flags);
        layoutWidget->setObjectName(QString::fromUtf8("layoutWidget"));
        layoutWidget->setGeometry(QRect(20, 32, 441, 111));
        verticalLayout_8 = new QVBoxLayout(layoutWidget);
        verticalLayout_8->setObjectName(QString::fromUtf8("verticalLayout_8"));
        verticalLayout_8->setContentsMargins(0, 0, 0, 0);
        chkNoteResume = new QCheckBox(layoutWidget);
        chkNoteResume->setObjectName(QString::fromUtf8("chkNoteResume"));
        chkNoteResume->setFont(font2);

        verticalLayout_8->addWidget(chkNoteResume);

        chkUseFilesPPQN = new QCheckBox(layoutWidget);
        chkUseFilesPPQN->setObjectName(QString::fromUtf8("chkUseFilesPPQN"));
        chkUseFilesPPQN->setFont(font2);

        verticalLayout_8->addWidget(chkUseFilesPPQN);

        chkSongRecordSnap = new QCheckBox(layoutWidget);
        chkSongRecordSnap->setObjectName(QString::fromUtf8("chkSongRecordSnap"));
        chkSongRecordSnap->setFont(font2);

        verticalLayout_8->addWidget(chkSongRecordSnap);

        chkAddTimeSig = new QCheckBox(layoutWidget);
        chkAddTimeSig->setObjectName(QString::fromUtf8("chkAddTimeSig"));
        chkAddTimeSig->setFont(font2);

        verticalLayout_8->addWidget(chkAddTimeSig);

        group_setsmode = new QGroupBox(tabPlayOptions);
        group_setsmode->setObjectName(QString::fromUtf8("group_setsmode"));
        group_setsmode->setGeometry(QRect(9, 220, 701, 132));
        group_setsmode->setMinimumSize(QSize(0, 132));
        group_setsmode->setFont(font1);
        radio_setsmode_normal = new QRadioButton(group_setsmode);
        radio_setsmode_normal->setObjectName(QString::fromUtf8("radio_setsmode_normal"));
        radio_setsmode_normal->setGeometry(QRect(24, 24, 500, 23));
        radio_setsmode_normal->setFont(font2);
        radio_setsmode_autoarm = new QRadioButton(group_setsmode);
        radio_setsmode_autoarm->setObjectName(QString::fromUtf8("radio_setsmode_autoarm"));
        radio_setsmode_autoarm->setGeometry(QRect(24, 48, 500, 23));
        radio_setsmode_autoarm->setFont(font2);
        radio_setsmode_additive = new QRadioButton(group_setsmode);
        radio_setsmode_additive->setObjectName(QString::fromUtf8("radio_setsmode_additive"));
        radio_setsmode_additive->setGeometry(QRect(24, 72, 500, 23));
        radio_setsmode_additive->setFont(font2);
        radio_setsmode_allsets = new QRadioButton(group_setsmode);
        radio_setsmode_allsets->setObjectName(QString::fromUtf8("radio_setsmode_allsets"));
        radio_setsmode_allsets->setGeometry(QRect(24, 96, 500, 23));
        radio_setsmode_allsets->setFont(font2);
        group_startmode = new QGroupBox(tabPlayOptions);
        group_startmode->setObjectName(QString::fromUtf8("group_startmode"));
        group_startmode->setGeometry(QRect(9, 360, 701, 111));
        group_startmode->setMinimumSize(QSize(0, 108));
        group_startmode->setMaximumSize(QSize(16777215, 16777215));
        group_startmode->setFont(font1);
        radio_startmode_live = new QRadioButton(group_startmode);
        radio_startmode_live->setObjectName(QString::fromUtf8("radio_startmode_live"));
        radio_startmode_live->setGeometry(QRect(24, 24, 500, 23));
        radio_startmode_live->setFont(font2);
        radio_startmode_song = new QRadioButton(group_startmode);
        radio_startmode_song->setObjectName(QString::fromUtf8("radio_startmode_song"));
        radio_startmode_song->setGeometry(QRect(24, 48, 500, 23));
        radio_startmode_song->setFont(font2);
        radio_startmode_auto = new QRadioButton(group_startmode);
        radio_startmode_auto->setObjectName(QString::fromUtf8("radio_startmode_auto"));
        radio_startmode_auto->setGeometry(QRect(24, 72, 500, 23));
        radio_startmode_auto->setFont(font2);
        label_ppqn = new QLabel(tabPlayOptions);
        label_ppqn->setObjectName(QString::fromUtf8("label_ppqn"));
        label_ppqn->setGeometry(QRect(20, 180, 61, 21));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_ppqn->sizePolicy().hasHeightForWidth());
        label_ppqn->setSizePolicy(sizePolicy1);
        label_ppqn->setMaximumSize(QSize(120, 16777215));
        label_ppqn->setFont(font1);
        label_ppqn->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        label_ppqn_2 = new QLabel(tabPlayOptions);
        label_ppqn_2->setObjectName(QString::fromUtf8("label_ppqn_2"));
        label_ppqn_2->setGeometry(QRect(220, 185, 460, 18));
        label_ppqn_2->setMinimumSize(QSize(460, 0));
        label_ppqn_2->setMaximumSize(QSize(200, 16777215));
        label_ppqn_2->setFont(font2);
        combo_box_ppqn = new QComboBox(tabPlayOptions);
        combo_box_ppqn->setObjectName(QString::fromUtf8("combo_box_ppqn"));
        combo_box_ppqn->setGeometry(QRect(100, 180, 100, 26));
        combo_box_ppqn->setMaximumSize(QSize(100, 16777215));
        combo_box_ppqn->setEditable(true);
        combo_box_ppqn->setMaxCount(32);
        combo_box_ppqn->setInsertPolicy(QComboBox::InsertPolicy::NoInsert);
        combo_box_ppqn->setFrame(true);
        groupBox_5 = new QGroupBox(tabPlayOptions);
        groupBox_5->setObjectName(QString::fromUtf8("groupBox_5"));
        groupBox_5->setGeometry(QRect(10, 170, 701, 41));
        QFont font6;
        font6.setFamily(QString::fromUtf8("aakar"));
        font6.setPointSize(11);
        font6.setBold(true);
        groupBox_5->setFont(font6);
        tabWidget->addTab(tabPlayOptions, QString());
        groupBox_5->raise();
        group_flags->raise();
        group_setsmode->raise();
        group_startmode->raise();
        label_ppqn->raise();
        label_ppqn_2->raise();
        combo_box_ppqn->raise();
        tabMetronome = new QWidget();
        tabMetronome->setObjectName(QString::fromUtf8("tabMetronome"));
        metroLayoutWidget = new QWidget(tabMetronome);
        metroLayoutWidget->setObjectName(QString::fromUtf8("metroLayoutWidget"));
        metroLayoutWidget->setGeometry(QRect(20, 20, 203, 200));
        verticalLayout_2 = new QVBoxLayout(metroLayoutWidget);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        label_metro_timesig = new QLabel(metroLayoutWidget);
        label_metro_timesig->setObjectName(QString::fromUtf8("label_metro_timesig"));
        label_metro_timesig->setFont(font1);
        label_metro_timesig->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout_2->addWidget(label_metro_timesig);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        label_metro_beat_width = new QLabel(metroLayoutWidget);
        label_metro_beat_width->setObjectName(QString::fromUtf8("label_metro_beat_width"));
        label_metro_beat_width->setFont(font2);
        label_metro_beat_width->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_metro_beat_width, 1, 0, 1, 1);

        lineedit_metro_beats_per_bar = new QLineEdit(metroLayoutWidget);
        lineedit_metro_beats_per_bar->setObjectName(QString::fromUtf8("lineedit_metro_beats_per_bar"));

        gridLayout_3->addWidget(lineedit_metro_beats_per_bar, 0, 1, 1, 1);

        label_metro_bpb = new QLabel(metroLayoutWidget);
        label_metro_bpb->setObjectName(QString::fromUtf8("label_metro_bpb"));
        label_metro_bpb->setFont(font2);
        label_metro_bpb->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_metro_bpb, 0, 0, 1, 1);

        lineedit_metro_beat_width = new QLineEdit(metroLayoutWidget);
        lineedit_metro_beat_width->setObjectName(QString::fromUtf8("lineedit_metro_beat_width"));

        gridLayout_3->addWidget(lineedit_metro_beat_width, 1, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_3->addItem(verticalSpacer_2, 2, 0, 1, 1);

        gridLayout_3->setColumnStretch(0, 6);
        gridLayout_3->setColumnStretch(1, 2);

        verticalLayout_2->addLayout(gridLayout_3);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        label_metro_count = new QLabel(metroLayoutWidget);
        label_metro_count->setObjectName(QString::fromUtf8("label_metro_count"));
        label_metro_count->setEnabled(true);
        label_metro_count->setFont(font1);

        gridLayout_4->addWidget(label_metro_count, 0, 1, 1, 1);

        label_metro_count_in = new QLabel(metroLayoutWidget);
        label_metro_count_in->setObjectName(QString::fromUtf8("label_metro_count_in"));
        label_metro_count_in->setEnabled(true);
        label_metro_count_in->setFont(font1);

        gridLayout_4->addWidget(label_metro_count_in, 0, 0, 1, 1);

        lineedit_metro_count_in = new QLineEdit(metroLayoutWidget);
        lineedit_metro_count_in->setObjectName(QString::fromUtf8("lineedit_metro_count_in"));
        lineedit_metro_count_in->setEnabled(true);

        gridLayout_4->addWidget(lineedit_metro_count_in, 1, 1, 1, 1);

        checkbox_metro_count_in = new QCheckBox(metroLayoutWidget);
        checkbox_metro_count_in->setObjectName(QString::fromUtf8("checkbox_metro_count_in"));
        checkbox_metro_count_in->setEnabled(true);

        gridLayout_4->addWidget(checkbox_metro_count_in, 1, 0, 1, 1);

        checkbox_metro_recording = new QCheckBox(metroLayoutWidget);
        checkbox_metro_recording->setObjectName(QString::fromUtf8("checkbox_metro_recording"));

        gridLayout_4->addWidget(checkbox_metro_recording, 2, 0, 1, 1);

        lineedit_metro_recording_measures = new QLineEdit(metroLayoutWidget);
        lineedit_metro_recording_measures->setObjectName(QString::fromUtf8("lineedit_metro_recording_measures"));

        gridLayout_4->addWidget(lineedit_metro_recording_measures, 2, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_4);

        metroLayoutWidget2 = new QWidget(tabMetronome);
        metroLayoutWidget2->setObjectName(QString::fromUtf8("metroLayoutWidget2"));
        metroLayoutWidget2->setGeometry(QRect(222, 20, 325, 201));
        verticalLayout_4 = new QVBoxLayout(metroLayoutWidget2);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        verticalLayout_4->setContentsMargins(6, 0, 0, 0);
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        gridLayout_2->setHorizontalSpacing(8);
        label_output_specs = new QLabel(metroLayoutWidget2);
        label_output_specs->setObjectName(QString::fromUtf8("label_output_specs"));
        label_output_specs->setFont(font1);
        label_output_specs->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout_2->addWidget(label_output_specs, 0, 0, 1, 1);

        label_metro_main_note = new QLabel(metroLayoutWidget2);
        label_metro_main_note->setObjectName(QString::fromUtf8("label_metro_main_note"));
        label_metro_main_note->setFont(font1);

        gridLayout_2->addWidget(label_metro_main_note, 0, 1, 1, 1);

        label_metro_sub_notes = new QLabel(metroLayoutWidget2);
        label_metro_sub_notes->setObjectName(QString::fromUtf8("label_metro_sub_notes"));
        label_metro_sub_notes->setFont(font1);

        gridLayout_2->addWidget(label_metro_sub_notes, 0, 2, 1, 1);

        label_metro_patch = new QLabel(metroLayoutWidget2);
        label_metro_patch->setObjectName(QString::fromUtf8("label_metro_patch"));
        label_metro_patch->setFont(font2);
        label_metro_patch->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_metro_patch, 1, 0, 1, 1);

        lineedit_metro_main_patch = new QLineEdit(metroLayoutWidget2);
        lineedit_metro_main_patch->setObjectName(QString::fromUtf8("lineedit_metro_main_patch"));

        gridLayout_2->addWidget(lineedit_metro_main_patch, 1, 1, 1, 1);

        lineedit_metro_sub_patch = new QLineEdit(metroLayoutWidget2);
        lineedit_metro_sub_patch->setObjectName(QString::fromUtf8("lineedit_metro_sub_patch"));

        gridLayout_2->addWidget(lineedit_metro_sub_patch, 1, 2, 1, 1);

        label_metro_note = new QLabel(metroLayoutWidget2);
        label_metro_note->setObjectName(QString::fromUtf8("label_metro_note"));
        label_metro_note->setFont(font2);
        label_metro_note->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_metro_note, 2, 0, 1, 1);

        lineedit_metro_main_note = new QLineEdit(metroLayoutWidget2);
        lineedit_metro_main_note->setObjectName(QString::fromUtf8("lineedit_metro_main_note"));

        gridLayout_2->addWidget(lineedit_metro_main_note, 2, 1, 1, 1);

        lineedit_metro_sub_note = new QLineEdit(metroLayoutWidget2);
        lineedit_metro_sub_note->setObjectName(QString::fromUtf8("lineedit_metro_sub_note"));

        gridLayout_2->addWidget(lineedit_metro_sub_note, 2, 2, 1, 1);

        label_metro_velocity = new QLabel(metroLayoutWidget2);
        label_metro_velocity->setObjectName(QString::fromUtf8("label_metro_velocity"));
        label_metro_velocity->setFont(font2);
        label_metro_velocity->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_metro_velocity, 3, 0, 1, 1);

        lineedit_metro_main_velocity = new QLineEdit(metroLayoutWidget2);
        lineedit_metro_main_velocity->setObjectName(QString::fromUtf8("lineedit_metro_main_velocity"));

        gridLayout_2->addWidget(lineedit_metro_main_velocity, 3, 1, 1, 1);

        lineedit_metro_sub_velocity = new QLineEdit(metroLayoutWidget2);
        lineedit_metro_sub_velocity->setObjectName(QString::fromUtf8("lineedit_metro_sub_velocity"));

        gridLayout_2->addWidget(lineedit_metro_sub_velocity, 3, 2, 1, 1);

        label_metro_length_fraction = new QLabel(metroLayoutWidget2);
        label_metro_length_fraction->setObjectName(QString::fromUtf8("label_metro_length_fraction"));
        label_metro_length_fraction->setFont(font2);
        label_metro_length_fraction->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_metro_length_fraction, 4, 0, 1, 1);

        lineedit_metro_main_fraction = new QLineEdit(metroLayoutWidget2);
        lineedit_metro_main_fraction->setObjectName(QString::fromUtf8("lineedit_metro_main_fraction"));

        gridLayout_2->addWidget(lineedit_metro_main_fraction, 4, 1, 1, 1);

        lineedit_metro_sub_fraction = new QLineEdit(metroLayoutWidget2);
        lineedit_metro_sub_fraction->setObjectName(QString::fromUtf8("lineedit_metro_sub_fraction"));

        gridLayout_2->addWidget(lineedit_metro_sub_fraction, 4, 2, 1, 1);

        gridLayout_2->setColumnStretch(0, 3);
        gridLayout_2->setColumnStretch(1, 1);
        gridLayout_2->setColumnStretch(2, 1);

        verticalLayout_4->addLayout(gridLayout_2);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_3);

        button_metro_reload = new QPushButton(metroLayoutWidget2);
        button_metro_reload->setObjectName(QString::fromUtf8("button_metro_reload"));
        button_metro_reload->setMinimumSize(QSize(225, 28));

        verticalLayout_4->addWidget(button_metro_reload);

        layoutWidgetMetro = new QWidget(tabMetronome);
        layoutWidgetMetro->setObjectName(QString::fromUtf8("layoutWidgetMetro"));
        layoutWidgetMetro->setGeometry(QRect(21, 260, 521, 105));
        verticalLayout_5 = new QVBoxLayout(layoutWidgetMetro);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label_metro_buss = new QLabel(layoutWidgetMetro);
        label_metro_buss->setObjectName(QString::fromUtf8("label_metro_buss"));
        label_metro_buss->setMinimumSize(QSize(100, 28));
        label_metro_buss->setFont(font1);

        horizontalLayout->addWidget(label_metro_buss);

        combobox_metro_buss = new QComboBox(layoutWidgetMetro);
        combobox_metro_buss->setObjectName(QString::fromUtf8("combobox_metro_buss"));
        combobox_metro_buss->setMinimumSize(QSize(266, 28));
        combobox_metro_buss->setMaximumSize(QSize(268, 28));

        horizontalLayout->addWidget(combobox_metro_buss);

        label_metro_channel = new QLabel(layoutWidgetMetro);
        label_metro_channel->setObjectName(QString::fromUtf8("label_metro_channel"));
        label_metro_channel->setFont(font1);
        label_metro_channel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout->addWidget(label_metro_channel);

        combobox_metro_channel = new QComboBox(layoutWidgetMetro);
        combobox_metro_channel->setObjectName(QString::fromUtf8("combobox_metro_channel"));
        combobox_metro_channel->setMinimumSize(QSize(64, 28));
        combobox_metro_channel->setMaximumSize(QSize(64, 28));

        horizontalLayout->addWidget(combobox_metro_channel);

        horizontalLayout->setStretch(0, 1);
        horizontalLayout->setStretch(1, 4);
        horizontalLayout->setStretch(2, 1);
        horizontalLayout->setStretch(3, 2);

        verticalLayout_5->addLayout(horizontalLayout);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        label_record_bus = new QLabel(layoutWidgetMetro);
        label_record_bus->setObjectName(QString::fromUtf8("label_record_bus"));
        label_record_bus->setMinimumSize(QSize(100, 28));
        label_record_bus->setFont(font1);

        horizontalLayout_4->addWidget(label_record_bus);

        combobox_metro_record_buss = new QComboBox(layoutWidgetMetro);
        combobox_metro_record_buss->setObjectName(QString::fromUtf8("combobox_metro_record_buss"));
        combobox_metro_record_buss->setMinimumSize(QSize(266, 28));
        combobox_metro_record_buss->setMaximumSize(QSize(266, 28));

        horizontalLayout_4->addWidget(combobox_metro_record_buss);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);


        verticalLayout_5->addLayout(horizontalLayout_4);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        label_metro_thru_buss = new QLabel(layoutWidgetMetro);
        label_metro_thru_buss->setObjectName(QString::fromUtf8("label_metro_thru_buss"));
        label_metro_thru_buss->setMinimumSize(QSize(100, 28));
        label_metro_thru_buss->setFont(font1);

        horizontalLayout_5->addWidget(label_metro_thru_buss);

        combobox_metro_thru_buss = new QComboBox(layoutWidgetMetro);
        combobox_metro_thru_buss->setObjectName(QString::fromUtf8("combobox_metro_thru_buss"));
        combobox_metro_thru_buss->setMinimumSize(QSize(266, 28));
        combobox_metro_thru_buss->setMaximumSize(QSize(266, 28));

        horizontalLayout_5->addWidget(combobox_metro_thru_buss);

        label_metro_thru_channel = new QLabel(layoutWidgetMetro);
        label_metro_thru_channel->setObjectName(QString::fromUtf8("label_metro_thru_channel"));
        label_metro_thru_channel->setFont(font1);
        label_metro_thru_channel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_5->addWidget(label_metro_thru_channel);

        combobox_metro_thru_channel = new QComboBox(layoutWidgetMetro);
        combobox_metro_thru_channel->setObjectName(QString::fromUtf8("combobox_metro_thru_channel"));
        combobox_metro_thru_channel->setMinimumSize(QSize(64, 28));
        combobox_metro_thru_channel->setMaximumSize(QSize(64, 28));

        horizontalLayout_5->addWidget(combobox_metro_thru_channel);

        horizontalLayout_5->setStretch(0, 1);
        horizontalLayout_5->setStretch(1, 4);
        horizontalLayout_5->setStretch(2, 1);
        horizontalLayout_5->setStretch(3, 2);

        verticalLayout_5->addLayout(horizontalLayout_5);

        groupBox_6 = new QGroupBox(tabMetronome);
        groupBox_6->setObjectName(QString::fromUtf8("groupBox_6"));
        groupBox_6->setGeometry(QRect(10, 10, 571, 231));
        groupBox_7 = new QGroupBox(tabMetronome);
        groupBox_7->setObjectName(QString::fromUtf8("groupBox_7"));
        groupBox_7->setGeometry(QRect(10, 250, 571, 121));
        tabWidget->addTab(tabMetronome, QString());
        groupBox_7->raise();
        groupBox_6->raise();
        metroLayoutWidget->raise();
        metroLayoutWidget2->raise();
        layoutWidgetMetro->raise();
        tabPattern = new QWidget();
        tabPattern->setObjectName(QString::fromUtf8("tabPattern"));
        groupBoxNewPattern = new QGroupBox(tabPattern);
        groupBoxNewPattern->setObjectName(QString::fromUtf8("groupBoxNewPattern"));
        groupBoxNewPattern->setGeometry(QRect(24, 10, 217, 441));
        groupBoxNewPattern->setFont(font2);
        layoutWidget1 = new QWidget(groupBoxNewPattern);
        layoutWidget1->setObjectName(QString::fromUtf8("layoutWidget1"));
        layoutWidget1->setGeometry(QRect(8, 40, 191, 344));
        verticalLayout_7 = new QVBoxLayout(layoutWidget1);
        verticalLayout_7->setSpacing(13);
        verticalLayout_7->setObjectName(QString::fromUtf8("verticalLayout_7"));
        verticalLayout_7->setContentsMargins(0, 0, 0, 0);
        verticalLayout_6 = new QVBoxLayout();
        verticalLayout_6->setObjectName(QString::fromUtf8("verticalLayout_6"));
        checkBoxNewPatternArm = new QCheckBox(layoutWidget1);
        checkBoxNewPatternArm->setObjectName(QString::fromUtf8("checkBoxNewPatternArm"));

        verticalLayout_6->addWidget(checkBoxNewPatternArm);

        checkBoxNewPatternRecord = new QCheckBox(layoutWidget1);
        checkBoxNewPatternRecord->setObjectName(QString::fromUtf8("checkBoxNewPatternRecord"));

        verticalLayout_6->addWidget(checkBoxNewPatternRecord);

        checkBoxNewPatternTighten = new QCheckBox(layoutWidget1);
        checkBoxNewPatternTighten->setObjectName(QString::fromUtf8("checkBoxNewPatternTighten"));

        verticalLayout_6->addWidget(checkBoxNewPatternTighten);

        checkBoxNewPatternQRecord = new QCheckBox(layoutWidget1);
        checkBoxNewPatternQRecord->setObjectName(QString::fromUtf8("checkBoxNewPatternQRecord"));

        verticalLayout_6->addWidget(checkBoxNewPatternQRecord);

        checkBoxNewPatternNoteMap = new QCheckBox(layoutWidget1);
        checkBoxNewPatternNoteMap->setObjectName(QString::fromUtf8("checkBoxNewPatternNoteMap"));

        verticalLayout_6->addWidget(checkBoxNewPatternNoteMap);

        checkBoxNewPatternWrapAround = new QCheckBox(layoutWidget1);
        checkBoxNewPatternWrapAround->setObjectName(QString::fromUtf8("checkBoxNewPatternWrapAround"));

        verticalLayout_6->addWidget(checkBoxNewPatternWrapAround);

        checkBoxNewPatternThru = new QCheckBox(layoutWidget1);
        checkBoxNewPatternThru->setObjectName(QString::fromUtf8("checkBoxNewPatternThru"));

        verticalLayout_6->addWidget(checkBoxNewPatternThru);


        verticalLayout_7->addLayout(verticalLayout_6);

        checkBoxNewApply = new QCheckBox(layoutWidget1);
        checkBoxNewApply->setObjectName(QString::fromUtf8("checkBoxNewApply"));

        verticalLayout_7->addWidget(checkBoxNewApply);

        labelRecordStyle = new QLabel(layoutWidget1);
        labelRecordStyle->setObjectName(QString::fromUtf8("labelRecordStyle"));
        labelRecordStyle->setFont(font1);
        labelRecordStyle->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        verticalLayout_7->addWidget(labelRecordStyle);

        comboBoxRecordStyle = new QComboBox(layoutWidget1);
        comboBoxRecordStyle->setObjectName(QString::fromUtf8("comboBoxRecordStyle"));
        comboBoxRecordStyle->setMinimumSize(QSize(0, 28));
        comboBoxRecordStyle->setMaxVisibleItems(8);
        comboBoxRecordStyle->setMaxCount(5);

        verticalLayout_7->addWidget(comboBoxRecordStyle);

        groupBoxRandomization = new QGroupBox(tabPattern);
        groupBoxRandomization->setObjectName(QString::fromUtf8("groupBoxRandomization"));
        groupBoxRandomization->setGeometry(QRect(250, 10, 401, 131));
        layoutWidgetRandomization = new QWidget(groupBoxRandomization);
        layoutWidgetRandomization->setObjectName(QString::fromUtf8("layoutWidgetRandomization"));
        layoutWidgetRandomization->setGeometry(QRect(16, 40, 259, 88));
        gridLayout_6 = new QGridLayout(layoutWidgetRandomization);
        gridLayout_6->setObjectName(QString::fromUtf8("gridLayout_6"));
        gridLayout_6->setContentsMargins(0, 0, 0, 0);
        spinBoxJitter = new QSpinBox(layoutWidgetRandomization);
        spinBoxJitter->setObjectName(QString::fromUtf8("spinBoxJitter"));
        spinBoxJitter->setMinimumSize(QSize(65, 28));
        spinBoxJitter->setMinimum(2);
        spinBoxJitter->setMaximum(64);
        spinBoxJitter->setValue(16);

        gridLayout_6->addWidget(spinBoxJitter, 0, 1, 1, 1);

        spinBoxAmplitude = new QSpinBox(layoutWidgetRandomization);
        spinBoxAmplitude->setObjectName(QString::fromUtf8("spinBoxAmplitude"));
        spinBoxAmplitude->setMinimumSize(QSize(65, 28));
        spinBoxAmplitude->setMinimum(1);
        spinBoxAmplitude->setMaximum(20);

        gridLayout_6->addWidget(spinBoxAmplitude, 1, 1, 1, 1);

        labelJitter = new QLabel(layoutWidgetRandomization);
        labelJitter->setObjectName(QString::fromUtf8("labelJitter"));
        labelJitter->setFont(font2);
        labelJitter->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_6->addWidget(labelJitter, 0, 0, 1, 1);

        labelMidiUnits = new QLabel(layoutWidgetRandomization);
        labelMidiUnits->setObjectName(QString::fromUtf8("labelMidiUnits"));
        labelMidiUnits->setFont(font2);

        gridLayout_6->addWidget(labelMidiUnits, 1, 2, 1, 1);

        labelJitter2 = new QLabel(layoutWidgetRandomization);
        labelJitter2->setObjectName(QString::fromUtf8("labelJitter2"));
        labelJitter2->setFont(font2);

        gridLayout_6->addWidget(labelJitter2, 0, 2, 1, 1);

        labelAmplitude = new QLabel(layoutWidgetRandomization);
        labelAmplitude->setObjectName(QString::fromUtf8("labelAmplitude"));
        labelAmplitude->setFont(font2);
        labelAmplitude->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_6->addWidget(labelAmplitude, 1, 0, 1, 1);

        groupBoxUsrOptions = new QGroupBox(tabPattern);
        groupBoxUsrOptions->setObjectName(QString::fromUtf8("groupBoxUsrOptions"));
        groupBoxUsrOptions->setGeometry(QRect(250, 160, 401, 111));
        checkBoxEscapePattern = new QCheckBox(groupBoxUsrOptions);
        checkBoxEscapePattern->setObjectName(QString::fromUtf8("checkBoxEscapePattern"));
        checkBoxEscapePattern->setGeometry(QRect(20, 40, 371, 28));
        checkBoxEscapePattern->setFont(font2);
        label_23 = new QLabel(groupBoxUsrOptions);
        label_23->setObjectName(QString::fromUtf8("label_23"));
        label_23->setGeometry(QRect(10, 10, 261, 18));
        label_23->setFont(font1);
        checkBoxSMF0_to_1 = new QCheckBox(groupBoxUsrOptions);
        checkBoxSMF0_to_1->setObjectName(QString::fromUtf8("checkBoxSMF0_to_1"));
        checkBoxSMF0_to_1->setGeometry(QRect(20, 70, 371, 23));
        checkBoxSMF0_to_1->setFont(font2);
        label_21 = new QLabel(tabPattern);
        label_21->setObjectName(QString::fromUtf8("label_21"));
        label_21->setGeometry(QRect(30, 20, 191, 18));
        label_21->setFont(font1);
        label_22 = new QLabel(tabPattern);
        label_22->setObjectName(QString::fromUtf8("label_22"));
        label_22->setGeometry(QRect(250, 20, 171, 18));
        label_22->setFont(font1);
        tabWidget->addTab(tabPattern, QString());
        tabSession = new QWidget();
        tabSession->setObjectName(QString::fromUtf8("tabSession"));
        group_session = new QGroupBox(tabSession);
        group_session->setObjectName(QString::fromUtf8("group_session"));
        group_session->setGeometry(QRect(8, 8, 301, 131));
        group_session->setFont(font2);
        radio_session_none = new QRadioButton(group_session);
        radio_session_none->setObjectName(QString::fromUtf8("radio_session_none"));
        radio_session_none->setGeometry(QRect(12, 32, 285, 23));
        radio_session_nsm = new QRadioButton(group_session);
        radio_session_nsm->setObjectName(QString::fromUtf8("radio_session_nsm"));
        radio_session_nsm->setGeometry(QRect(12, 64, 285, 23));
        radio_session_jack = new QRadioButton(group_session);
        radio_session_jack->setObjectName(QString::fromUtf8("radio_session_jack"));
        radio_session_jack->setGeometry(QRect(12, 96, 285, 23));
        label_10 = new QLabel(group_session);
        label_10->setObjectName(QString::fromUtf8("label_10"));
        label_10->setGeometry(QRect(8, 4, 105, 17));
        label_10->setFont(font1);
        label_session = new QLabel(tabSession);
        label_session->setObjectName(QString::fromUtf8("label_session"));
        label_session->setGeometry(QRect(336, 10, 341, 91));
        label_session->setFont(font5);
        label_nsm_url = new QLabel(tabSession);
        label_nsm_url->setObjectName(QString::fromUtf8("label_nsm_url"));
        label_nsm_url->setGeometry(QRect(16, 152, 149, 17));
        label_nsm_url->setFont(font1);
        lineEditNsmUrl = new QLineEdit(tabSession);
        lineEditNsmUrl->setObjectName(QString::fromUtf8("lineEditNsmUrl"));
        lineEditNsmUrl->setGeometry(QRect(44, 176, 233, 25));
        groupBoxSaveAtExit = new QGroupBox(tabSession);
        groupBoxSaveAtExit->setObjectName(QString::fromUtf8("groupBoxSaveAtExit"));
        groupBoxSaveAtExit->setGeometry(QRect(20, 210, 673, 231));
        checkBoxSaveRc = new QCheckBox(groupBoxSaveAtExit);
        checkBoxSaveRc->setObjectName(QString::fromUtf8("checkBoxSaveRc"));
        checkBoxSaveRc->setGeometry(QRect(36, 70, 96, 23));
        checkBoxSaveRc->setFont(font2);
        checkBoxSaveUsr = new QCheckBox(groupBoxSaveAtExit);
        checkBoxSaveUsr->setObjectName(QString::fromUtf8("checkBoxSaveUsr"));
        checkBoxSaveUsr->setEnabled(true);
        checkBoxSaveUsr->setGeometry(QRect(36, 100, 96, 23));
        checkBoxSaveUsr->setFont(font2);
        checkBoxSaveMutes = new QCheckBox(groupBoxSaveAtExit);
        checkBoxSaveMutes->setObjectName(QString::fromUtf8("checkBoxSaveMutes"));
        checkBoxSaveMutes->setGeometry(QRect(36, 130, 96, 23));
        checkBoxSaveMutes->setFont(font2);
        checkBoxSavePlaylist = new QCheckBox(groupBoxSaveAtExit);
        checkBoxSavePlaylist->setObjectName(QString::fromUtf8("checkBoxSavePlaylist"));
        checkBoxSavePlaylist->setGeometry(QRect(36, 160, 96, 23));
        checkBoxSavePlaylist->setFont(font2);
        checkBoxSaveCtrl = new QCheckBox(groupBoxSaveAtExit);
        checkBoxSaveCtrl->setObjectName(QString::fromUtf8("checkBoxSaveCtrl"));
        checkBoxSaveCtrl->setEnabled(true);
        checkBoxSaveCtrl->setGeometry(QRect(376, 70, 96, 23));
        checkBoxSaveCtrl->setFont(font2);
        checkBoxSaveDrums = new QCheckBox(groupBoxSaveAtExit);
        checkBoxSaveDrums->setObjectName(QString::fromUtf8("checkBoxSaveDrums"));
        checkBoxSaveDrums->setEnabled(false);
        checkBoxSaveDrums->setGeometry(QRect(376, 100, 96, 23));
        checkBoxSaveDrums->setFont(font2);
        checkBoxActiveRc = new QCheckBox(groupBoxSaveAtExit);
        checkBoxActiveRc->setObjectName(QString::fromUtf8("checkBoxActiveRc"));
        checkBoxActiveRc->setEnabled(false);
        checkBoxActiveRc->setGeometry(QRect(8, 70, 25, 23));
        checkBoxActiveRc->setChecked(true);
        checkBoxActiveUsr = new QCheckBox(groupBoxSaveAtExit);
        checkBoxActiveUsr->setObjectName(QString::fromUtf8("checkBoxActiveUsr"));
        checkBoxActiveUsr->setEnabled(true);
        checkBoxActiveUsr->setGeometry(QRect(8, 100, 25, 23));
        checkBoxActiveMutes = new QCheckBox(groupBoxSaveAtExit);
        checkBoxActiveMutes->setObjectName(QString::fromUtf8("checkBoxActiveMutes"));
        checkBoxActiveMutes->setEnabled(true);
        checkBoxActiveMutes->setGeometry(QRect(8, 130, 25, 23));
        checkBoxActivePlaylist = new QCheckBox(groupBoxSaveAtExit);
        checkBoxActivePlaylist->setObjectName(QString::fromUtf8("checkBoxActivePlaylist"));
        checkBoxActivePlaylist->setEnabled(true);
        checkBoxActivePlaylist->setGeometry(QRect(8, 160, 25, 23));
        checkBoxActiveCtrl = new QCheckBox(groupBoxSaveAtExit);
        checkBoxActiveCtrl->setObjectName(QString::fromUtf8("checkBoxActiveCtrl"));
        checkBoxActiveCtrl->setEnabled(true);
        checkBoxActiveCtrl->setGeometry(QRect(348, 70, 25, 23));
        checkBoxActiveDrums = new QCheckBox(groupBoxSaveAtExit);
        checkBoxActiveDrums->setObjectName(QString::fromUtf8("checkBoxActiveDrums"));
        checkBoxActiveDrums->setEnabled(true);
        checkBoxActiveDrums->setGeometry(QRect(348, 100, 25, 23));
        label_cfg_active = new QLabel(groupBoxSaveAtExit);
        label_cfg_active->setObjectName(QString::fromUtf8("label_cfg_active"));
        label_cfg_active->setGeometry(QRect(8, 36, 57, 17));
        QFont font7;
        font7.setPointSize(11);
        font7.setBold(true);
        font7.setItalic(true);
        label_cfg_active->setFont(font7);
        label_cfg_save = new QLabel(groupBoxSaveAtExit);
        label_cfg_save->setObjectName(QString::fromUtf8("label_cfg_save"));
        label_cfg_save->setGeometry(QRect(64, 36, 65, 17));
        label_cfg_save->setFont(font7);
        lineEditRc = new QLineEdit(groupBoxSaveAtExit);
        lineEditRc->setObjectName(QString::fromUtf8("lineEditRc"));
        lineEditRc->setEnabled(true);
        lineEditRc->setGeometry(QRect(140, 70, 144, 28));
        lineEditUsr = new QLineEdit(groupBoxSaveAtExit);
        lineEditUsr->setObjectName(QString::fromUtf8("lineEditUsr"));
        lineEditUsr->setEnabled(true);
        lineEditUsr->setGeometry(QRect(140, 100, 144, 28));
        lineEditMutes = new QLineEdit(groupBoxSaveAtExit);
        lineEditMutes->setObjectName(QString::fromUtf8("lineEditMutes"));
        lineEditMutes->setEnabled(true);
        lineEditMutes->setGeometry(QRect(140, 130, 144, 28));
        lineEditPlaylist = new QLineEdit(groupBoxSaveAtExit);
        lineEditPlaylist->setObjectName(QString::fromUtf8("lineEditPlaylist"));
        lineEditPlaylist->setEnabled(true);
        lineEditPlaylist->setGeometry(QRect(140, 160, 144, 28));
        lineEditCtrl = new QLineEdit(groupBoxSaveAtExit);
        lineEditCtrl->setObjectName(QString::fromUtf8("lineEditCtrl"));
        lineEditCtrl->setEnabled(true);
        lineEditCtrl->setGeometry(QRect(480, 70, 144, 28));
        lineEditDrums = new QLineEdit(groupBoxSaveAtExit);
        lineEditDrums->setObjectName(QString::fromUtf8("lineEditDrums"));
        lineEditDrums->setEnabled(true);
        lineEditDrums->setGeometry(QRect(480, 100, 144, 28));
        label_cfg_basename = new QLabel(groupBoxSaveAtExit);
        label_cfg_basename->setObjectName(QString::fromUtf8("label_cfg_basename"));
        label_cfg_basename->setGeometry(QRect(144, 36, 141, 17));
        label_cfg_basename->setFont(font7);
        lineEditPalette = new QLineEdit(groupBoxSaveAtExit);
        lineEditPalette->setObjectName(QString::fromUtf8("lineEditPalette"));
        lineEditPalette->setGeometry(QRect(140, 190, 144, 28));
        checkBoxActivePalette = new QCheckBox(groupBoxSaveAtExit);
        checkBoxActivePalette->setObjectName(QString::fromUtf8("checkBoxActivePalette"));
        checkBoxActivePalette->setGeometry(QRect(8, 190, 25, 23));
        checkBoxSavePalette = new QCheckBox(groupBoxSaveAtExit);
        checkBoxSavePalette->setObjectName(QString::fromUtf8("checkBoxSavePalette"));
        checkBoxSavePalette->setEnabled(false);
        checkBoxSavePalette->setGeometry(QRect(36, 190, 96, 23));
        checkBoxSavePalette->setFont(font2);
        label_cfg_active_2 = new QLabel(groupBoxSaveAtExit);
        label_cfg_active_2->setObjectName(QString::fromUtf8("label_cfg_active_2"));
        label_cfg_active_2->setGeometry(QRect(344, 36, 53, 17));
        label_cfg_active_2->setFont(font7);
        label_cfg_save_2 = new QLabel(groupBoxSaveAtExit);
        label_cfg_save_2->setObjectName(QString::fromUtf8("label_cfg_save_2"));
        label_cfg_save_2->setGeometry(QRect(400, 36, 53, 17));
        label_cfg_save_2->setFont(font7);
        label_cfg_basename_2 = new QLabel(groupBoxSaveAtExit);
        label_cfg_basename_2->setObjectName(QString::fromUtf8("label_cfg_basename_2"));
        label_cfg_basename_2->setGeometry(QRect(482, 36, 141, 17));
        label_cfg_basename_2->setFont(font7);
        checkBoxActiveStyleSheet = new QCheckBox(groupBoxSaveAtExit);
        checkBoxActiveStyleSheet->setObjectName(QString::fromUtf8("checkBoxActiveStyleSheet"));
        checkBoxActiveStyleSheet->setEnabled(true);
        checkBoxActiveStyleSheet->setGeometry(QRect(348, 130, 25, 23));
        checkBoxSaveStyleSheet = new QCheckBox(groupBoxSaveAtExit);
        checkBoxSaveStyleSheet->setObjectName(QString::fromUtf8("checkBoxSaveStyleSheet"));
        checkBoxSaveStyleSheet->setEnabled(false);
        checkBoxSaveStyleSheet->setGeometry(QRect(376, 130, 96, 23));
        checkBoxSaveStyleSheet->setFont(font2);
        lineEditStyleSheet = new QLineEdit(groupBoxSaveAtExit);
        lineEditStyleSheet->setObjectName(QString::fromUtf8("lineEditStyleSheet"));
        lineEditStyleSheet->setEnabled(true);
        lineEditStyleSheet->setGeometry(QRect(480, 130, 144, 28));
        pushButtonSavePalette = new QPushButton(groupBoxSaveAtExit);
        pushButtonSavePalette->setObjectName(QString::fromUtf8("pushButtonSavePalette"));
        pushButtonSavePalette->setGeometry(QRect(342, 190, 132, 28));
        pushButtonSavePalette->setFont(font2);
        label_11 = new QLabel(groupBoxSaveAtExit);
        label_11->setObjectName(QString::fromUtf8("label_11"));
        label_11->setGeometry(QRect(4, 4, 161, 17));
        label_11->setFont(font1);
        pushButtonLoadRc = new QPushButton(groupBoxSaveAtExit);
        pushButtonLoadRc->setObjectName(QString::fromUtf8("pushButtonLoadRc"));
        pushButtonLoadRc->setGeometry(QRect(292, 72, 28, 24));
        pushButtonLoadUsr = new QPushButton(groupBoxSaveAtExit);
        pushButtonLoadUsr->setObjectName(QString::fromUtf8("pushButtonLoadUsr"));
        pushButtonLoadUsr->setGeometry(QRect(292, 102, 28, 24));
        pushButtonLoadMutes = new QPushButton(groupBoxSaveAtExit);
        pushButtonLoadMutes->setObjectName(QString::fromUtf8("pushButtonLoadMutes"));
        pushButtonLoadMutes->setGeometry(QRect(292, 132, 28, 24));
        pushButtonLoadPlaylist = new QPushButton(groupBoxSaveAtExit);
        pushButtonLoadPlaylist->setObjectName(QString::fromUtf8("pushButtonLoadPlaylist"));
        pushButtonLoadPlaylist->setGeometry(QRect(292, 162, 28, 24));
        pushButtonLoadPalette = new QPushButton(groupBoxSaveAtExit);
        pushButtonLoadPalette->setObjectName(QString::fromUtf8("pushButtonLoadPalette"));
        pushButtonLoadPalette->setGeometry(QRect(292, 192, 28, 24));
        pushButtonLoadCtrl = new QPushButton(groupBoxSaveAtExit);
        pushButtonLoadCtrl->setObjectName(QString::fromUtf8("pushButtonLoadCtrl"));
        pushButtonLoadCtrl->setGeometry(QRect(631, 72, 28, 24));
        pushButtonLoadDrums = new QPushButton(groupBoxSaveAtExit);
        pushButtonLoadDrums->setObjectName(QString::fromUtf8("pushButtonLoadDrums"));
        pushButtonLoadDrums->setGeometry(QRect(632, 102, 28, 24));
        pushButtonLoadStyleSheet = new QPushButton(groupBoxSaveAtExit);
        pushButtonLoadStyleSheet->setObjectName(QString::fromUtf8("pushButtonLoadStyleSheet"));
        pushButtonLoadStyleSheet->setGeometry(QRect(632, 132, 28, 24));
        label_cannot_alter = new QLabel(groupBoxSaveAtExit);
        label_cannot_alter->setObjectName(QString::fromUtf8("label_cannot_alter"));
        label_cannot_alter->setGeometry(QRect(200, 2, 481, 22));
        label_cannot_alter->setFont(font4);
        checkBoxSavePatches = new QCheckBox(groupBoxSaveAtExit);
        checkBoxSavePatches->setObjectName(QString::fromUtf8("checkBoxSavePatches"));
        checkBoxSavePatches->setEnabled(false);
        checkBoxSavePatches->setGeometry(QRect(376, 158, 101, 28));
        checkBoxSavePatches->setFont(font2);
        checkBoxActivePatches = new QCheckBox(groupBoxSaveAtExit);
        checkBoxActivePatches->setObjectName(QString::fromUtf8("checkBoxActivePatches"));
        checkBoxActivePatches->setGeometry(QRect(348, 162, 21, 21));
        lineEditPatches = new QLineEdit(groupBoxSaveAtExit);
        lineEditPatches->setObjectName(QString::fromUtf8("lineEditPatches"));
        lineEditPatches->setGeometry(QRect(480, 160, 144, 28));
        pushButtonLoadPatches = new QPushButton(groupBoxSaveAtExit);
        pushButtonLoadPatches->setObjectName(QString::fromUtf8("pushButtonLoadPatches"));
        pushButtonLoadPatches->setGeometry(QRect(632, 163, 28, 24));
        pushButtonSavePatches = new QPushButton(groupBoxSaveAtExit);
        pushButtonSavePatches->setObjectName(QString::fromUtf8("pushButtonSavePatches"));
        pushButtonSavePatches->setGeometry(QRect(487, 190, 132, 28));
        pushButtonSavePatches->setFont(font2);
        label_exit_required = new QLabel(tabSession);
        label_exit_required->setObjectName(QString::fromUtf8("label_exit_required"));
        label_exit_required->setGeometry(QRect(330, 150, 341, 41));
        label_exit_required->setFont(font7);
        label_exit_required->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        label_3 = new QLabel(tabSession);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(10, 450, 101, 22));
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        label_24 = new QLabel(tabSession);
        label_24->setObjectName(QString::fromUtf8("label_24"));
        label_24->setGeometry(QRect(20, 485, 101, 22));
        label_24->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        lineEditBrowser = new QLineEdit(tabSession);
        lineEditBrowser->setObjectName(QString::fromUtf8("lineEditBrowser"));
        lineEditBrowser->setGeometry(QRect(140, 456, 491, 28));
        lineEditPdfViewer = new QLineEdit(tabSession);
        lineEditPdfViewer->setObjectName(QString::fromUtf8("lineEditPdfViewer"));
        lineEditPdfViewer->setGeometry(QRect(140, 486, 491, 28));
        pushButtonSetBrowser = new QPushButton(tabSession);
        pushButtonSetBrowser->setObjectName(QString::fromUtf8("pushButtonSetBrowser"));
        pushButtonSetBrowser->setGeometry(QRect(639, 459, 28, 24));
        pushButtonSetPdfViewer = new QPushButton(tabSession);
        pushButtonSetPdfViewer->setObjectName(QString::fromUtf8("pushButtonSetPdfViewer"));
        pushButtonSetPdfViewer->setGeometry(QRect(639, 490, 28, 24));
        groupBox_8 = new QGroupBox(tabSession);
        groupBox_8->setObjectName(QString::fromUtf8("groupBox_8"));
        groupBox_8->setGeometry(QRect(8, 139, 301, 71));
        pushButtonReload = new QPushButton(tabSession);
        pushButtonReload->setObjectName(QString::fromUtf8("pushButtonReload"));
        pushButtonReload->setEnabled(false);
        pushButtonReload->setGeometry(QRect(350, 110, 141, 25));
        pushButtonReload->setMaximumSize(QSize(16777215, 56));
        pushButtonReload->setFont(font2);
        tabWidget->addTab(tabSession, QString());
        groupBoxSaveAtExit->raise();
        groupBox_8->raise();
        group_session->raise();
        label_session->raise();
        label_nsm_url->raise();
        lineEditNsmUrl->raise();
        label_exit_required->raise();
        label_3->raise();
        label_24->raise();
        lineEditBrowser->raise();
        lineEditPdfViewer->raise();
        pushButtonSetBrowser->raise();
        pushButtonSetPdfViewer->raise();
        pushButtonReload->raise();

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(spinKeyHeight, lineEditUiScaling);
        QWidget::setTabOrder(lineEditUiScaling, lineEditUiScalingHeight);
        QWidget::setTabOrder(lineEditUiScalingHeight, lineEditSetSize);
        QWidget::setTabOrder(lineEditSetSize, lineEditSetSizeColumns);
        QWidget::setTabOrder(lineEditSetSizeColumns, lineEditProgressBox);
        QWidget::setTabOrder(lineEditProgressBox, lineEditProgressBoxHeight);
        QWidget::setTabOrder(lineEditProgressBoxHeight, lineEditFingerprintSize);
        QWidget::setTabOrder(lineEditFingerprintSize, checkBoxVerbose);
        QWidget::setTabOrder(checkBoxVerbose, checkBoxLoadMostRecent);
        QWidget::setTabOrder(checkBoxLoadMostRecent, checkBoxShowFullRecentPaths);
        QWidget::setTabOrder(checkBoxShowFullRecentPaths, pushButtonStoreMap);
        QWidget::setTabOrder(pushButtonStoreMap, pushButtonTempoTrack);
        QWidget::setTabOrder(pushButtonTempoTrack, ioPortsMappedCheck);
        QWidget::setTabOrder(ioPortsMappedCheck, lineEditTempoTrack);
        QWidget::setTabOrder(lineEditTempoTrack, lineEditClientId);
        QWidget::setTabOrder(lineEditClientId, clocksScrollArea);
        QWidget::setTabOrder(clocksScrollArea, checkBoxRecordByBuss);
        QWidget::setTabOrder(checkBoxRecordByBuss, inputsScrollArea);
        QWidget::setTabOrder(inputsScrollArea, btnJackConnect);
        QWidget::setTabOrder(btnJackConnect, btnJackDisconnect);
        QWidget::setTabOrder(btnJackDisconnect, chkJackConditional);
        QWidget::setTabOrder(chkJackConditional, chkJackMaster);
        QWidget::setTabOrder(chkJackMaster, chkJackTransport);
        QWidget::setTabOrder(chkJackTransport, chkJackNative);
        QWidget::setTabOrder(chkJackNative, radio_live_mode);
        QWidget::setTabOrder(radio_live_mode, radio_song_mode);
        QWidget::setTabOrder(radio_song_mode, chkNoteResume);
        QWidget::setTabOrder(chkNoteResume, chkUseFilesPPQN);
        QWidget::setTabOrder(chkUseFilesPPQN, combo_box_ppqn);
        QWidget::setTabOrder(combo_box_ppqn, spinBoxClockStartModulo);

        retranslateUi(qseditoptions);

        tabWidget->setCurrentIndex(4);


        QMetaObject::connectSlotsByName(qseditoptions);
    } // setupUi

    void retranslateUi(QDialog *qseditoptions)
    {
        qseditoptions->setWindowTitle(QCoreApplication::translate("qseditoptions", "Preferences", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tabMidiClock->setToolTip(QCoreApplication::translate("qseditoptions", "A list of MIDI output ports and clock settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBoxMetaEvents->setTitle(QString());
        label_meta_events->setText(QCoreApplication::translate("qseditoptions", "Meta Events", nullptr));
#if QT_CONFIG(tooltip)
        lineEditTempoTrack->setToolTip(QCoreApplication::translate("qseditoptions", "Change track to hold tempo.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditTempoTrack->setPlaceholderText(QCoreApplication::translate("qseditoptions", "0", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonTempoTrack->setToolTip(QCoreApplication::translate("qseditoptions", "Saves the tempo track number to the MIDI file.", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonTempoTrack->setText(QCoreApplication::translate("qseditoptions", "Set ", nullptr));
#if QT_CONFIG(tooltip)
        textLabelTempoTrack->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        textLabelTempoTrack->setText(QCoreApplication::translate("qseditoptions", "Tempo Track", nullptr));
        label_clock_precision->setText(QCoreApplication::translate("qseditoptions", "BPM Precision", nullptr));
        label->setText(QCoreApplication::translate("qseditoptions", "Client Name:ID/UUID", nullptr));
#if QT_CONFIG(tooltip)
        lineEditClientId->setToolTip(QCoreApplication::translate("qseditoptions", "Holds the MIDI client ID, as applicable.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditClientId->setPlaceholderText(QCoreApplication::translate("qseditoptions", "0", nullptr));
        portsClocksLabel->setText(QCoreApplication::translate("qseditoptions", "Ports and Clocking", nullptr));
        label_2->setText(QCoreApplication::translate("qseditoptions", "MIDI Clock", nullptr));
        checkBoxMidiOutBuss->setText(QString());
        labelMidiOutBuss->setText(QCoreApplication::translate("qseditoptions", "MIDI Ctrl Out (Display) Bus", nullptr));
#if QT_CONFIG(tooltip)
        labelClockStartModulo->setToolTip(QCoreApplication::translate("qseditoptions", "Sets the position after which MIDI clocking begins.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelClockStartModulo->setText(QCoreApplication::translate("qseditoptions", "Clock Start Modulo (ticks)", nullptr));
#if QT_CONFIG(tooltip)
        ioPortsMappedCheck->setToolTip(QCoreApplication::translate("qseditoptions", "If checked, the output port map was active.", nullptr));
#endif // QT_CONFIG(tooltip)
        ioPortsMappedCheck->setText(QCoreApplication::translate("qseditoptions", "MIDI I/O Port Maps", nullptr));
        label_20->setText(QCoreApplication::translate("qseditoptions", "Buss Override", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonStoreMap->setToolTip(QCoreApplication::translate("qseditoptions", "Saves maps of I/O port numbers and names to the 'rc' file.\n"
"Each port number can be found by name-lookup.", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonStoreMap->setText(QCoreApplication::translate("qseditoptions", "Recreate", nullptr));
        pushButtonRemoveMap->setText(QCoreApplication::translate("qseditoptions", "Clear", nullptr));
        groupBox_2->setTitle(QString());
        groupBox_10->setTitle(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabMidiClock), QCoreApplication::translate("qseditoptions", "MIDI &Clock", nullptr));
#if QT_CONFIG(tooltip)
        tabMidiInput->setToolTip(QCoreApplication::translate("qseditoptions", "Provides a table to select the desired MIDI input port.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBoxInputOptions->setTitle(QString());
        label_5->setText(QCoreApplication::translate("qseditoptions", "Input/Output Options", nullptr));
        checkBoxVirtualPorts->setText(QCoreApplication::translate("qseditoptions", "Use virtual (manual) I/O ports", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxRecordByBuss->setToolTip(QCoreApplication::translate("qseditoptions", "If checked, incoming data routes to the pattern\n"
"slot by channel number (0 to 15).", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxRecordByBuss->setText(QCoreApplication::translate("qseditoptions", "Record into patterns by bus (overrides channel)", nullptr));
        lineEditOutputCount->setText(QCoreApplication::translate("qseditoptions", "8", nullptr));
        label_outputs->setText(QCoreApplication::translate("qseditoptions", "Outputs", nullptr));
        lineEditInputCount->setText(QCoreApplication::translate("qseditoptions", "4", nullptr));
        checkBoxAutoEnableVirtual->setText(QCoreApplication::translate("qseditoptions", "Auto-enable virtual ports", nullptr));
        label_inputs->setText(QCoreApplication::translate("qseditoptions", "Inputs", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxRecordByChannel->setToolTip(QCoreApplication::translate("qseditoptions", "If checked, incoming data routes to the pattern\n"
"slot by bus/port number. Overrides input by\n"
"channel.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxRecordByChannel->setText(QCoreApplication::translate("qseditoptions", "Record into patterns by channel", nullptr));
        inputBussesLabel->setText(QCoreApplication::translate("qseditoptions", "Input Buses", nullptr));
        checkBoxMidiInBuss->setText(QString());
        labelMidiCtrlIn->setText(QCoreApplication::translate("qseditoptions", "MIDI Ctrl In (Automation) Bus", nullptr));
        groupBox_3->setTitle(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabMidiInput), QCoreApplication::translate("qseditoptions", "MIDI &Input", nullptr));
#if QT_CONFIG(tooltip)
        tabDisplay->setToolTip(QCoreApplication::translate("qseditoptions", "Provides some minor tweaks of the user-interface.  Edit the 'usr' file for far more control over settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBoxBooleanOptions->setTitle(QString());
#if QT_CONFIG(tooltip)
        checkBoxLongBussNames->setToolTip(QCoreApplication::translate("qseditoptions", "rc: [Seq66] port-naming = long", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxLongBussNames->setText(QCoreApplication::translate("qseditoptions", "Long port/buss names *", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxVerbose->setToolTip(QCoreApplication::translate("qseditoptions", "Shows the status of rc / [Seq66] / verbose.\n"
"Always set to false at exit.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxVerbose->setText(QCoreApplication::translate("qseditoptions", "Verbose console output", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxPairBussNames->setToolTip(QCoreApplication::translate("qseditoptions", "rc: [Seq66] port-naming = pair", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxPairBussNames->setText(QCoreApplication::translate("qseditoptions", "Client:port buss names *", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxGlobalSeqFeature->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-interface-settings] global-seq-feature", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxGlobalSeqFeature->setText(QCoreApplication::translate("qseditoptions", "Global background/scale/key", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxDoubleClickEdit->setToolTip(QCoreApplication::translate("qseditoptions", "rc: [interaction-method] double-click-edit", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxDoubleClickEdit->setText(QCoreApplication::translate("qseditoptions", "Double click for pattern editor", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxQuiet->setToolTip(QCoreApplication::translate("qseditoptions", "Enable to suppress error prompts at startup.\n"
"Useful if the prompts are going to be ignored\n"
"anyway.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxQuiet->setText(QCoreApplication::translate("qseditoptions", "Suppress startup error messages", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxSwapCoordinates->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-interface-settings] swap-coordinates", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxSwapCoordinates->setText(QCoreApplication::translate("qseditoptions", "Swap grid coordinates (be aware!)", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxDarkTheme->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-interface-settings] dark-theme\n"
"Applies a couple of color tweaks, such as\n"
"using inverse font color for slots.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxDarkTheme->setText(QCoreApplication::translate("qseditoptions", "Tweak color for dark theme", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxElliptical->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-interface-settings] progress-box-elliptical\n"
"If set, the grid slot progress boxes are ellipses.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxElliptical->setText(QCoreApplication::translate("qseditoptions", "Elliptical progess box", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxShowFullRecentPaths->setToolTip(QCoreApplication::translate("qseditoptions", "rc: [recent-files] full-paths", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxShowFullRecentPaths->setText(QCoreApplication::translate("qseditoptions", "Show full path of recent files", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxLoadMostRecent->setToolTip(QCoreApplication::translate("qseditoptions", "Load most-recent file at startup. Works only if there\n"
"is no active playlist. rc: [recent-files] load-most-recent", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxLoadMostRecent->setText(QCoreApplication::translate("qseditoptions", "Load most-recent file (startup)", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxFollowProgress->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-interface-settings] follow-progress\n"
"Sets the default setting for the follow-progress\n"
"button in the piano rolls.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxFollowProgress->setText(QCoreApplication::translate("qseditoptions", "Follow progress by default", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxBoldGridSlots->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-interface-settings] progress-bar-thick", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxBoldGridSlots->setText(QCoreApplication::translate("qseditoptions", "Bold grid slot font/box", nullptr));
        label_7->setText(QCoreApplication::translate("qseditoptions", "UI Boolean Options", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxLockMainWindow->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-ui-tweaks] lock-main-window", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxLockMainWindow->setText(QCoreApplication::translate("qseditoptions", "Lock main window", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxGridlinesThick->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-interface-settings] gridlines-thick", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxGridlinesThick->setText(QCoreApplication::translate("qseditoptions", "Thick grid lines", nullptr));
        checkBox_2->setText(QCoreApplication::translate("qseditoptions", "Reserved", nullptr));
        checkBoxProgressBoxShown->setText(QCoreApplication::translate("qseditoptions", "Shown", nullptr));
#if QT_CONFIG(tooltip)
        lineEditUiScalingHeight->setToolTip(QCoreApplication::translate("qseditoptions", "Scales the height of main window at startup.\n"
"Range: 0.5 to 3.0", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditUiScalingHeight->setText(QCoreApplication::translate("qseditoptions", "1.0", nullptr));
#if QT_CONFIG(tooltip)
        lineEditSetSize->setToolTip(QCoreApplication::translate("qseditoptions", "Set the set-size rows.\n"
"Range: 4 to 8. Default: 4.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditSetSize->setText(QCoreApplication::translate("qseditoptions", "4", nullptr));
#if QT_CONFIG(tooltip)
        labelProgressBoxSize->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-ui-tweaks] progress-box-width, -height", nullptr));
#endif // QT_CONFIG(tooltip)
        labelProgressBoxSize->setText(QCoreApplication::translate("qseditoptions", "Progress boxes (fraction)", nullptr));
#if QT_CONFIG(tooltip)
        lineEditFingerprintSize->setToolTip(QCoreApplication::translate("qseditoptions", "An abbreviated display of a long pattern to save CPU time.\n"
"If more notes than this value, a fingerprint is shown.\n"
"Range: 32 to 128, 0 disables.  Default: 32.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditFingerprintSize->setText(QCoreApplication::translate("qseditoptions", "32", nullptr));
#if QT_CONFIG(tooltip)
        labelFingerprintSize->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-ui-tweaks] fingerprint-size", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFingerprintSize->setText(QCoreApplication::translate("qseditoptions", "Fingerprint size", nullptr));
#if QT_CONFIG(tooltip)
        labelEditorKeyHeight->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-ui-tweaks] key-height", nullptr));
#endif // QT_CONFIG(tooltip)
        labelEditorKeyHeight->setText(QCoreApplication::translate("qseditoptions", "Editor key height", nullptr));
#if QT_CONFIG(tooltip)
        lineEditSetSizeColumns->setToolTip(QCoreApplication::translate("qseditoptions", "Set the set-size columns.\n"
"Range: 4 to 12. Default: 8.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditSetSizeColumns->setText(QCoreApplication::translate("qseditoptions", "8", nullptr));
#if QT_CONFIG(tooltip)
        lineEditProgressBoxHeight->setToolTip(QCoreApplication::translate("qseditoptions", "Heights of the progress box as a fraction of button height. Range: 0.1 to 1.0. Default: 0.4.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditProgressBoxHeight->setText(QCoreApplication::translate("qseditoptions", "0.4", nullptr));
#if QT_CONFIG(tooltip)
        lineEditProgressBox->setToolTip(QCoreApplication::translate("qseditoptions", "Width of the progress box as a fraction of button width.\n"
"Range: 0.5 to 1.0. Default: 0.8.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditProgressBox->setText(QCoreApplication::translate("qseditoptions", "0.8", nullptr));
        label_x2->setText(QCoreApplication::translate("qseditoptions", "x", nullptr));
#if QT_CONFIG(tooltip)
        spinKeyHeight->setToolTip(QCoreApplication::translate("qseditoptions", "Sets default height of piano keys in the pattern editor.\n"
"Ranges from 6 to 32.  The \"-0+\" buttons or \"v0V\" keys\n"
"zoom vertically.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_x->setText(QCoreApplication::translate("qseditoptions", "x", nullptr));
#if QT_CONFIG(tooltip)
        labelSetSizeRows->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-interface-settings] mainwnd-rows, -columns", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSetSizeRows->setText(QCoreApplication::translate("qseditoptions", "Set size (rows x columns)", nullptr));
        label_x3->setText(QCoreApplication::translate("qseditoptions", "x", nullptr));
#if QT_CONFIG(tooltip)
        labelUiScaling->setToolTip(QCoreApplication::translate("qseditoptions", "usr: [user-interface-settings] window-scale, -y", nullptr));
#endif // QT_CONFIG(tooltip)
        labelUiScaling->setText(QCoreApplication::translate("qseditoptions", "Grid scaling & spacing", nullptr));
#if QT_CONFIG(tooltip)
        lineEditUiScaling->setToolTip(QCoreApplication::translate("qseditoptions", "Scales the width of the main window at startup.\n"
"Range: 0.5 to 3.0", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditUiScaling->setText(QCoreApplication::translate("qseditoptions", "1.0", nullptr));
        labelRestartNeeded->setText(QCoreApplication::translate("qseditoptions", "Restart needed for most settings", nullptr));
        label_6->setText(QCoreApplication::translate("qseditoptions", "User UI Tweaks", nullptr));
        label_19->setText(QCoreApplication::translate("qseditoptions", "* Ignored if port-mapping (the default) is enabled", nullptr));
        groupBox_4->setTitle(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabDisplay), QCoreApplication::translate("qseditoptions", "&Display", nullptr));
#if QT_CONFIG(tooltip)
        tabJackSync->setToolTip(QCoreApplication::translate("qseditoptions", "Provides settings for JACK transport and JACK MIDI.", nullptr));
#endif // QT_CONFIG(tooltip)
        r_group_jack_transport->setTitle(QString());
        label_8->setText(QCoreApplication::translate("qseditoptions", "JACK Transport/MIDI", nullptr));
        label_4->setText(QCoreApplication::translate("qseditoptions", "JACK Server Settings", nullptr));
        label_12->setText(QCoreApplication::translate("qseditoptions", "Frame rate", nullptr));
#if QT_CONFIG(tooltip)
        lineEditFrameRate->setToolTip(QCoreApplication::translate("qseditoptions", "The number of JACK frames per second.\n"
"48000 Hz by default.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(QCoreApplication::translate("qseditoptions", "Period size", nullptr));
#if QT_CONFIG(tooltip)
        lineEditPeriod->setToolTip(QCoreApplication::translate("qseditoptions", "The number of frames in a period.  A period\n"
"is a \"cycle\", and is the number of frames in\n"
"a period and the number frames between\n"
"JACK process callbacks.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_15->setText(QCoreApplication::translate("qseditoptions", "N periods", nullptr));
#if QT_CONFIG(tooltip)
        lineEditNperiod->setToolTip(QCoreApplication::translate("qseditoptions", "The number of ALSA periods, 2 by default,\n"
"3 recommended for USB.  Also called \"latency\".\n"
"Does not effect the time between process\n"
"callbacks.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_16->setText(QCoreApplication::translate("qseditoptions", "JACK ticks/beat", nullptr));
#if QT_CONFIG(tooltip)
        lineEditTicksPerBeat->setToolTip(QCoreApplication::translate("qseditoptions", "Indicates the number of JACK ticks per\n"
"beat, normally PPQN/10.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_17->setText(QCoreApplication::translate("qseditoptions", "Beats/minute", nullptr));
#if QT_CONFIG(tooltip)
        lineEditBeatsPerMinute->setToolTip(QCoreApplication::translate("qseditoptions", "JACK's current beats/minute setting.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_18->setText(QCoreApplication::translate("qseditoptions", "Period override", nullptr));
        alsaJackButton->setText(QCoreApplication::translate("qseditoptions", "PortMIDI", nullptr));
#if QT_CONFIG(tooltip)
        chkJackConditional->setToolTip(QCoreApplication::translate("qseditoptions", "Sets Seq66 as the MIDI Master if no master exists.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkJackConditional->setText(QCoreApplication::translate("qseditoptions", "Master conditional", nullptr));
#if QT_CONFIG(tooltip)
        chkJackMaster->setToolTip(QCoreApplication::translate("qseditoptions", "Sets Seq66 as the MIDI Master.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkJackMaster->setText(QCoreApplication::translate("qseditoptions", "Transport master", nullptr));
#if QT_CONFIG(tooltip)
        chkJackTransport->setToolTip(QCoreApplication::translate("qseditoptions", "Turns on Seq66 JACK transport as a client.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkJackTransport->setText(QCoreApplication::translate("qseditoptions", "Enable JACK transport", nullptr));
#if QT_CONFIG(tooltip)
        chkJackNative->setToolTip(QCoreApplication::translate("qseditoptions", "Requests Seq66 to use the JACK system if it is running.\n"
"Otherwise, ALSA is used.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkJackNative->setText(QCoreApplication::translate("qseditoptions", "Native JACK &MIDI (requires a restart)", nullptr));
#if QT_CONFIG(tooltip)
        chkJackAutoConnect->setToolTip(QCoreApplication::translate("qseditoptions", "If checked (the default), then Seq66 automatically\n"
"connects to the MIDI I/O ports it finds.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkJackAutoConnect->setText(QCoreApplication::translate("qseditoptions", "JACK auto-connect", nullptr));
        r_group_jack_start->setTitle(QString());
        label_9->setText(QCoreApplication::translate("qseditoptions", "JACK/ALSA Current Start Mode", nullptr));
        label_14->setText(QCoreApplication::translate("qseditoptions", "(See Play tab for user's\n"
"setting of Start mode)", nullptr));
#if QT_CONFIG(tooltip)
        radio_live_mode->setToolTip(QCoreApplication::translate("qseditoptions", "Play MIDI in Live Mode:  each pattern plays in an endless loop.", nullptr));
#endif // QT_CONFIG(tooltip)
        radio_live_mode->setText(QCoreApplication::translate("qseditoptions", "&Live mode", nullptr));
#if QT_CONFIG(tooltip)
        radio_song_mode->setToolTip(QCoreApplication::translate("qseditoptions", "Play MIDI in Song Mode: playback controlled by the layout\n"
"in the Song Editor.", nullptr));
#endif // QT_CONFIG(tooltip)
        radio_song_mode->setText(QCoreApplication::translate("qseditoptions", "&Song mode", nullptr));
        label_25->setText(QCoreApplication::translate("qseditoptions", "JACK Transport", nullptr));
#if QT_CONFIG(tooltip)
        btnJackConnect->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        btnJackConnect->setText(QCoreApplication::translate("qseditoptions", "Co&nnect", nullptr));
#if QT_CONFIG(tooltip)
        btnJackDisconnect->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        btnJackDisconnect->setText(QCoreApplication::translate("qseditoptions", "&Disconnect", nullptr));
        groupBox->setTitle(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabJackSync), QCoreApplication::translate("qseditoptions", "&JACK", nullptr));
#if QT_CONFIG(tooltip)
        tabPlayOptions->setToolTip(QCoreApplication::translate("qseditoptions", "Provides play options.  Minimal at present.", nullptr));
#endif // QT_CONFIG(tooltip)
        group_flags->setTitle(QCoreApplication::translate("qseditoptions", "Flags", nullptr));
#if QT_CONFIG(tooltip)
        chkNoteResume->setToolTip(QCoreApplication::translate("qseditoptions", "Unfinished notes are turned back on when\n"
"playback resumes.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkNoteResume->setText(QCoreApplication::translate("qseditoptions", "&Resume Note Ons at start/stop or sequence toggle.", nullptr));
#if QT_CONFIG(tooltip)
        chkUseFilesPPQN->setToolTip(QCoreApplication::translate("qseditoptions", "The PPQN of the MIDI file loaded overrides the\n"
"default PPQN.  Otherwise, the file PPQN scales to\n"
"the default PPQN.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkUseFilesPPQN->setText(QCoreApplication::translate("qseditoptions", "Use file's PPQN for pre-existing files (recommended).", nullptr));
#if QT_CONFIG(tooltip)
        chkSongRecordSnap->setToolTip(QCoreApplication::translate("qseditoptions", "Employ the snap interval when recording\n"
"song triggers.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkSongRecordSnap->setText(QCoreApplication::translate("qseditoptions", "Song-record snap.", nullptr));
#if QT_CONFIG(tooltip)
        chkAddTimeSig->setToolTip(QCoreApplication::translate("qseditoptions", "Automatically add the starting time signature as\n"
"an event in the new pattern.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkAddTimeSig->setText(QCoreApplication::translate("qseditoptions", "Automatically add starting time signature event.", nullptr));
        group_setsmode->setTitle(QCoreApplication::translate("qseditoptions", "Sets Mode", nullptr));
        radio_setsmode_normal->setText(QCoreApplication::translate("qseditoptions", "Normal. Only the active set (\"play-screen\") can be armed.", nullptr));
        radio_setsmode_autoarm->setText(QCoreApplication::translate("qseditoptions", "Auto-Arm. When moving to the ne&xt set, it automatically arms.", nullptr));
        radio_setsmode_additive->setText(QCoreApplication::translate("qseditoptions", "Additive. As each sets is activated, the others keep playing.", nullptr));
        radio_setsmode_allsets->setText(QCoreApplication::translate("qseditoptions", "All Sets.  All sets can play at the same time.", nullptr));
        group_startmode->setTitle(QCoreApplication::translate("qseditoptions", "Song Start Mode", nullptr));
        radio_startmode_live->setText(QCoreApplication::translate("qseditoptions", "Li&ve. Musician controls arming/muting.", nullptr));
        radio_startmode_song->setText(QCoreApplication::translate("qseditoptions", "Song. Song-editor layout controls arming/muting.", nullptr));
        radio_startmode_auto->setText(QCoreApplication::translate("qseditoptions", "Auto. Song mode is used if a song-editor layout exists.", nullptr));
        label_ppqn->setText(QCoreApplication::translate("qseditoptions", "PPQN ", nullptr));
        label_ppqn_2->setText(QCoreApplication::translate("qseditoptions", "Base Seq66 PPQN for new or converted files.", nullptr));
#if QT_CONFIG(tooltip)
        combo_box_ppqn->setToolTip(QCoreApplication::translate("qseditoptions", "Changes the default PPQN from 192 to another value.\n"
"Saved in the 'usr' file when Seq66 exits.", nullptr));
#endif // QT_CONFIG(tooltip)
        combo_box_ppqn->setCurrentText(QCoreApplication::translate("qseditoptions", "9600", nullptr));
        groupBox_5->setTitle(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabPlayOptions), QCoreApplication::translate("qseditoptions", "&Play", nullptr));
        label_metro_timesig->setText(QCoreApplication::translate("qseditoptions", "Time Signature", nullptr));
        label_metro_beat_width->setText(QCoreApplication::translate("qseditoptions", "Beat width", nullptr));
        label_metro_bpb->setText(QCoreApplication::translate("qseditoptions", "Beats/bar", nullptr));
        label_metro_count->setText(QCoreApplication::translate("qseditoptions", "Measures", nullptr));
        label_metro_count_in->setText(QCoreApplication::translate("qseditoptions", "Count-In", nullptr));
        checkbox_metro_count_in->setText(QCoreApplication::translate("qseditoptions", "Enabled", nullptr));
        checkbox_metro_recording->setText(QCoreApplication::translate("qseditoptions", "Recording", nullptr));
        label_output_specs->setText(QCoreApplication::translate("qseditoptions", "Output Specs", nullptr));
        label_metro_main_note->setText(QCoreApplication::translate("qseditoptions", "Main Note", nullptr));
        label_metro_sub_notes->setText(QCoreApplication::translate("qseditoptions", "Sub Notes", nullptr));
        label_metro_patch->setText(QCoreApplication::translate("qseditoptions", "Patch", nullptr));
        label_metro_note->setText(QCoreApplication::translate("qseditoptions", "Note", nullptr));
        label_metro_velocity->setText(QCoreApplication::translate("qseditoptions", "Velocity", nullptr));
        label_metro_length_fraction->setText(QCoreApplication::translate("qseditoptions", "Length fraction", nullptr));
        button_metro_reload->setText(QCoreApplication::translate("qseditoptions", "Reload Metronome", nullptr));
        label_metro_buss->setText(QCoreApplication::translate("qseditoptions", "Metro buss", nullptr));
        label_metro_channel->setText(QCoreApplication::translate("qseditoptions", "Channel", nullptr));
        label_record_bus->setText(QCoreApplication::translate("qseditoptions", "Record buss", nullptr));
        label_metro_thru_buss->setText(QCoreApplication::translate("qseditoptions", "Thru buss", nullptr));
        label_metro_thru_channel->setText(QCoreApplication::translate("qseditoptions", "Channel", nullptr));
        groupBox_6->setTitle(QString());
        groupBox_7->setTitle(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabMetronome), QCoreApplication::translate("qseditoptions", "&Metronome", nullptr));
        groupBoxNewPattern->setTitle(QString());
        checkBoxNewPatternArm->setText(QCoreApplication::translate("qseditoptions", "Armed", nullptr));
        checkBoxNewPatternRecord->setText(QCoreApplication::translate("qseditoptions", "Record", nullptr));
        checkBoxNewPatternTighten->setText(QCoreApplication::translate("qseditoptions", "Tighten record", nullptr));
        checkBoxNewPatternQRecord->setText(QCoreApplication::translate("qseditoptions", "Quantize record", nullptr));
        checkBoxNewPatternNoteMap->setText(QCoreApplication::translate("qseditoptions", "Note-map record", nullptr));
        checkBoxNewPatternWrapAround->setText(QCoreApplication::translate("qseditoptions", "Wrap-around", nullptr));
        checkBoxNewPatternThru->setText(QCoreApplication::translate("qseditoptions", "MIDI Thru", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxNewApply->setToolTip(QCoreApplication::translate("qseditoptions", "If checked, apply options only when a new\n"
"pattern editor is opened.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxNewApply->setText(QCoreApplication::translate("qseditoptions", "Apply only to new", nullptr));
        labelRecordStyle->setText(QCoreApplication::translate("qseditoptions", "Record Loop Style", nullptr));
        comboBoxRecordStyle->setCurrentText(QString());
        groupBoxRandomization->setTitle(QString());
#if QT_CONFIG(tooltip)
        spinBoxJitter->setToolTip(QCoreApplication::translate("qseditoptions", "The amount of time randomization to apply\n"
"with jitter application.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        spinBoxAmplitude->setToolTip(QCoreApplication::translate("qseditoptions", "Amplitude of randomization for items that range from\n"
"0 to 127. Set this before application.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelJitter->setText(QCoreApplication::translate("qseditoptions", "Jitter 1/", nullptr));
        labelMidiUnits->setText(QCoreApplication::translate("qseditoptions", "in MIDI units", nullptr));
        labelJitter2->setText(QCoreApplication::translate("qseditoptions", "of Snap", nullptr));
        labelAmplitude->setText(QCoreApplication::translate("qseditoptions", "Amplitude", nullptr));
        groupBoxUsrOptions->setTitle(QString());
#if QT_CONFIG(tooltip)
        checkBoxEscapePattern->setToolTip(QCoreApplication::translate("qseditoptions", "Overloads the Esc key to use as a Close key", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxEscapePattern->setText(QCoreApplication::translate("qseditoptions", "Esc key in piano roll closes external editor", nullptr));
        label_23->setText(QCoreApplication::translate("qseditoptions", "Additional 'usr' Options", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxSMF0_to_1->setToolTip(QCoreApplication::translate("qseditoptions", "If set, split an SMF 0 file into multiple tracks", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxSMF0_to_1->setText(QCoreApplication::translate("qseditoptions", "Automatic conversion of SMF 0 to SMF 1", nullptr));
#if QT_CONFIG(tooltip)
        label_21->setToolTip(QCoreApplication::translate("qseditoptions", "Pattern status options to apply when creating/opening a pattern.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_21->setText(QCoreApplication::translate("qseditoptions", "Pattern Editor Options", nullptr));
        label_22->setText(QCoreApplication::translate("qseditoptions", "Randomization", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabPattern), QCoreApplication::translate("qseditoptions", "P&attern", nullptr));
        group_session->setTitle(QString());
        radio_session_none->setText(QCoreApplication::translate("qseditoptions", "None. Normal Se&q66 operation.", nullptr));
        radio_session_nsm->setText(QCoreApplication::translate("qseditoptions", "NSM. NSM debug mode.", nullptr));
        radio_session_jack->setText(QCoreApplication::translate("qseditoptions", "JACK. JACK session management.", nullptr));
        label_10->setText(QCoreApplication::translate("qseditoptions", "Session", nullptr));
        label_session->setText(QCoreApplication::translate("qseditoptions", "NSM use is automatic if Seq66 runs in an \n"
"NSM session.  The check-mark causes Seq66\n"
"to run as if in NSM, for debugging. JACK \n"
"session management occurs only if checked, \n"
"even if Seq66 is run by it.", nullptr));
        label_nsm_url->setText(QCoreApplication::translate("qseditoptions", "UUID/NSM URL", nullptr));
        groupBoxSaveAtExit->setTitle(QString());
        checkBoxSaveRc->setText(QCoreApplication::translate("qseditoptions", ".rc", nullptr));
        checkBoxSaveUsr->setText(QCoreApplication::translate("qseditoptions", ".usr", nullptr));
        checkBoxSaveMutes->setText(QCoreApplication::translate("qseditoptions", ".mutes", nullptr));
        checkBoxSavePlaylist->setText(QCoreApplication::translate("qseditoptions", ".playlist", nullptr));
        checkBoxSaveCtrl->setText(QCoreApplication::translate("qseditoptions", ".ctrl +", nullptr));
        checkBoxSaveDrums->setText(QCoreApplication::translate("qseditoptions", ".drums +", nullptr));
        checkBoxActiveRc->setText(QString());
        checkBoxActiveUsr->setText(QString());
        checkBoxActiveMutes->setText(QString());
        checkBoxActivePlaylist->setText(QString());
        checkBoxActiveCtrl->setText(QString());
        checkBoxActiveDrums->setText(QString());
        label_cfg_active->setText(QCoreApplication::translate("qseditoptions", "Active", nullptr));
        label_cfg_save->setText(QCoreApplication::translate("qseditoptions", "Save", nullptr));
        label_cfg_basename->setText(QCoreApplication::translate("qseditoptions", "Base Filename", nullptr));
#if QT_CONFIG(tooltip)
        lineEditPalette->setToolTip(QCoreApplication::translate("qseditoptions", "Provides the base name of the palette file.  This file\n"
"always resides in the Seq66 configuration directory\n"
"(~/.config/seq66 or the NSM session directory). Any\n"
"path added to this name is stripped.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditPalette->setText(QString());
        checkBoxActivePalette->setText(QString());
        checkBoxSavePalette->setText(QCoreApplication::translate("qseditoptions", ".palette +", nullptr));
        label_cfg_active_2->setText(QCoreApplication::translate("qseditoptions", "Active", nullptr));
        label_cfg_save_2->setText(QCoreApplication::translate("qseditoptions", "Save", nullptr));
        label_cfg_basename_2->setText(QCoreApplication::translate("qseditoptions", "Base Filename", nullptr));
        checkBoxActiveStyleSheet->setText(QString());
        checkBoxSaveStyleSheet->setText(QCoreApplication::translate("qseditoptions", ".qss +", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonSavePalette->setToolTip(QCoreApplication::translate("qseditoptions", "Useful for storing updates to Seq66's palette layout.", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonSavePalette->setText(QCoreApplication::translate("qseditoptions", "&Store Palette", nullptr));
        label_11->setText(QCoreApplication::translate("qseditoptions", "Configuration Files", nullptr));
        pushButtonLoadRc->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
        pushButtonLoadUsr->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
        pushButtonLoadMutes->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
        pushButtonLoadPlaylist->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
        pushButtonLoadPalette->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
        pushButtonLoadCtrl->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
        pushButtonLoadDrums->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
        pushButtonLoadStyleSheet->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
        label_cannot_alter->setText(QCoreApplication::translate("qseditoptions", "+ Cannot alter data for these files in Seq66. Text-edit them.", nullptr));
        checkBoxSavePatches->setText(QCoreApplication::translate("qseditoptions", ".patches +", nullptr));
        checkBoxActivePatches->setText(QString());
        pushButtonLoadPatches->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonSavePatches->setToolTip(QCoreApplication::translate("qseditoptions", "Useful for creating or copying a patches file.", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonSavePatches->setText(QCoreApplication::translate("qseditoptions", "Store Patches", nullptr));
        label_exit_required->setText(QCoreApplication::translate("qseditoptions", "* The changes made require a complete\n"
"   exit and re-run. Save your work first.", nullptr));
        label_3->setText(QCoreApplication::translate("qseditoptions", "Browser", nullptr));
        label_24->setText(QCoreApplication::translate("qseditoptions", "PDF Viewer", nullptr));
#if QT_CONFIG(tooltip)
        lineEditBrowser->setToolTip(QCoreApplication::translate("qseditoptions", "Specifies an alternate browser executable such as\n"
"/usr/bin/evince. The complete path is not needed if in one's\n"
"PATH.\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        lineEditPdfViewer->setToolTip(QCoreApplication::translate("qseditoptions", "Specifies an alternate PDF viewer such as\n"
"C:/Users/user/AppData/Local/Apps/Evince-2.32.0.145/bin/evince.exe\n"
"or /usr/bin/zathura.\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pushButtonSetBrowser->setToolTip(QCoreApplication::translate("qseditoptions", "Click to open a file dialog to set the browser.", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonSetBrowser->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonSetPdfViewer->setToolTip(QCoreApplication::translate("qseditoptions", "Click to open a file dialog to set the PDF viewer.", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonSetPdfViewer->setText(QCoreApplication::translate("qseditoptions", "...", nullptr));
        groupBox_8->setTitle(QString());
#if QT_CONFIG(tooltip)
        pushButtonReload->setToolTip(QCoreApplication::translate("qseditoptions", "Restarts the whole application, reloading any changed settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonReload->setText(QCoreApplication::translate("qseditoptions", "Restart Session", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabSession), QCoreApplication::translate("qseditoptions", "Sessio&n", nullptr));
    } // retranslateUi

};

namespace Ui {
    class qseditoptions: public Ui_qseditoptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QSEDITOPTIONS_H
